function [residual, g1, g2, g3] = GB_No_MaP_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 72, 1);

%
% Model equations
%

T183 = (1-params(12))*(exp(y(20))-exp(y(10))*params(19)*exp(y(12)))/params(12);
T186 = params(66)*((-y(57))+exp(y(19))*y(57)+exp(y(40))*(y(65)-1)*params(14)+exp(y(10))*exp(y(14))+T183-exp(y(10))*params(19)*exp(y(12)));
T206 = exp(y(18))*(-params(1))/(1-params(1));
T235 = (1-params(13))*(exp(y(24))-exp(y(11))*params(20)*exp(y(13)))/params(13);
T241 = (1-params(1))/params(1);
T264 = exp(y(8))^(1-params(14));
T268 = exp(y(36))^params(14);
T271 = exp(y(12))^(params(14)-1);
T279 = exp(y(9))^(1-params(14));
T283 = exp(y(37))^params(14);
T285 = exp(y(13))^(params(14)-1);
T302 = exp(y(14))/(exp(y(12))*params(18));
T303 = T302-1;
T304 = params(22)*T303;
T305 = exp(y(14))/exp(y(12));
T306 = T305^2;
T321 = exp(y(15))/(exp(y(13))*params(18));
T322 = T321-1;
T323 = params(22)*T322;
T324 = exp(y(15))/exp(y(13));
T325 = T324^2;
T334 = exp(y(34))*(1-params(14))*exp(y(8))^(-params(14));
T336 = (exp(y(12))*exp(y(36)))^params(14);
T337 = T334*T336;
T340 = exp(y(7))^(-params(26));
T347 = (1-params(14))*exp(y(35))*exp(y(9))^(-params(14));
T349 = (exp(y(13))*exp(y(37)))^params(14);
T350 = T347*T349;
T351 = exp(y(6))^(-params(26));
T362 = params(22)/2;
T379 = exp(y(14))*(1+(1-params(23))*T362*T303^2);
T385 = exp(y(15))*(1+(1-params(23))*T362*T322^2);
T421 = params(1)/(1-params(1));
T435 = exp(y(30))*(1+params(27)*(1-params(12)+params(12)*exp(y(22)))-params(27));
T453 = exp(y(31))*(1+params(27)*(1-params(13)+params(13)*exp(y(26)))-params(27));
lhs =y(5);
rhs =params(63)*params(71)*params(1)*y(3)+params(64)*params(72)*(1-params(1))*y(4);
residual(1)= lhs-rhs;
lhs =y(66);
rhs =params(63)*params(71)*params(1)*y(67)+params(64)*params(72)*(1-params(1))*y(68);
residual(2)= lhs-rhs;
lhs =y(3);
rhs =y(7)-params(21)*(exp(y(8))+params(65)*y(51))^(1+params(25))/(1+params(25))-y(51)*(1-params(65));
residual(3)= lhs-rhs;
lhs =y(4);
rhs =y(6)-params(21)*(exp(y(9))+params(65)*y(52))^(1+params(25))/(1+params(25))-(1-params(65))*y(52);
residual(4)= lhs-rhs;
lhs =y(67);
rhs =y(7)-params(21)*exp(y(8))^(1+params(25))/(1+params(25));
residual(5)= lhs-rhs;
lhs =y(68);
rhs =y(6)-params(21)*exp(y(9))^(1+params(25))/(1+params(25));
residual(6)= lhs-rhs;
lhs =y(51);
rhs =params(60)*params(36)^2+params(61)*(y(65)-params(36))+0.5*params(62)*(y(65)-params(36))^2;
residual(7)= lhs-rhs;
lhs =y(52);
rhs =params(60)*params(37)^2+params(61)*(y(64)-params(37))+0.5*params(62)*(y(64)-params(37))^2;
residual(8)= lhs-rhs;
lhs =exp(y(19))*exp(y(30));
rhs =1;
residual(9)= lhs-rhs;
lhs =exp(y(18))*exp(y(31));
rhs =1;
residual(10)= lhs-rhs;
residual(11) = params(51)*(y(7)-params(96)-y(6)+params(97)+params(59)*y(63)^2)+(1-params(51))*(exp(y(30))*exp(y(18))*exp(params(7)*(y(17)-params(94)))-1);
residual(12) = exp(y(40))-exp(y(7))-exp(y(32))+params(51)*(y(50)-exp(y(30))*y(50)+params(66)*((-y(17))+exp(y(18))*y(17)))+(1-params(51))*((-y(17))+exp(y(18))*y(17))+T186;
lhs =y(71);
rhs =exp(y(40))+params(51)*params(66)*exp(y(18))*y(17)+(1-params(51))*exp(y(18))*y(17)+params(66)*(T183+exp(y(19))*y(57)+exp(y(10))*exp(y(14))-exp(y(32)));
residual(13)= lhs-rhs;
lhs =y(72);
rhs =exp(y(41))+params(51)*params(66)*y(17)*T206+(1-params(51))*y(17)*T206+params(66)*(exp(y(18))*y(58)+exp(y(11))*exp(y(15))-exp(y(33))+T235);
residual(14)= lhs-rhs;
residual(15) = exp(y(40))-exp(y(7))-exp(y(32))+T186+T241*(exp(y(41))-exp(y(6))-exp(y(33))+params(66)*(T235+exp(y(11))*exp(y(15))+exp(y(41))*params(14)*(y(64)-1)+exp(y(18))*y(58)-y(58)-exp(y(11))*params(20)*exp(y(13))));
lhs =exp(y(1));
rhs =params(14)*exp(y(34))*T264*T268*T271;
residual(16)= lhs-rhs;
lhs =exp(y(2));
rhs =params(14)*exp(y(35))*T279*T283*T285;
residual(17)= lhs-rhs;
lhs =exp(y(10))*exp(y(27));
rhs =exp(y(1))*(1-y(65))+exp(y(10))*exp(y(36))*(1-params(18))+(1-params(23))*T304*T306/params(18);
residual(18)= lhs-rhs;
lhs =exp(y(11))*exp(y(28));
rhs =exp(y(2))*(1-y(64))+exp(y(11))*exp(y(37))*(1-params(18))+(1-params(23))*T323*T325/params(18);
residual(19)= lhs-rhs;
lhs =T337*T340;
rhs =params(21)*(exp(y(8))+params(65)*y(51))^params(25);
residual(20)= lhs-rhs;
lhs =T350*T351;
rhs =params(21)*(exp(y(9))+params(65)*y(52))^params(25);
residual(21)= lhs-rhs;
lhs =exp(y(12));
rhs =exp(y(14))+exp(y(12))*exp(y(36))*(1-params(18));
residual(22)= lhs-rhs;
lhs =exp(y(13));
rhs =exp(y(15))+exp(y(13))*exp(y(37))*(1-params(18));
residual(23)= lhs-rhs;
lhs =exp(y(10));
rhs =1+(1-params(23))*T304;
residual(24)= lhs-rhs;
lhs =exp(y(11));
rhs =1+(1-params(23))*T323;
residual(25)= lhs-rhs;
lhs =exp(y(32));
rhs =T379;
residual(26)= lhs-rhs;
lhs =exp(y(33));
rhs =T385;
residual(27)= lhs-rhs;
residual(28) = params(51)*(y(17)-params(94))+(1-params(51))*y(50);
lhs =T336*exp(y(34))*T264;
rhs =exp(y(40));
residual(29)= lhs-rhs;
lhs =T349*exp(y(35))*T279;
rhs =exp(y(41));
residual(30)= lhs-rhs;
lhs =exp(y(23));
rhs =(1-params(38))*(exp(y(16))-exp(y(19))+exp(y(19))*params(55))/params(55)+exp(y(19))*params(38);
residual(31)= lhs-rhs;
residual(32) = params(38)*y(29)+(1-params(38))*(y(29)*(params(55)-1)-y(57));
lhs =y(58);
rhs =params(66)*(exp(y(11))*exp(y(13))+y(29)*T421-exp(y(24)));
residual(33)= lhs-rhs;
residual(34) = T435*(exp(y(27))-exp(y(23)))-y(21)*params(30)*exp(y(38));
lhs =T453*(exp(y(28))-exp(y(18)));
rhs =params(28)*exp(y(39))*y(25);
residual(35)= lhs-rhs;
residual(36) = exp(y(22))*(1-y(21))-exp(y(23))*T435;
residual(37) = (-exp(y(26)))*(1-y(25))+exp(y(18))*T453;
residual(38) = params(27)*(exp(y(20))*exp(y(22))-exp(y(12))*exp(y(10))*params(30)*exp(y(38)))+y(21)*(1-params(27));
lhs =exp(y(20));
rhs =(1-params(66))*exp(params(98))+params(66)*(exp(y(10))*params(19)*exp(y(12))+params(12)*(exp(y(12))*exp(y(10))*exp(y(27))-exp(y(23))*(y(57)+y(29))));
residual(39)= lhs-rhs;
lhs =exp(y(24));
rhs =(1-params(66))*exp(params(99))+params(66)*(exp(y(11))*params(20)*exp(y(13))+params(13)*(exp(y(13))*exp(y(11))*exp(y(28))+exp(y(16))*y(29)*T421-exp(y(18))*y(58)));
residual(40)= lhs-rhs;
lhs =T453*(exp(y(16))-exp(y(18)));
rhs =y(25)*exp(y(39))*params(29);
residual(41)= lhs-rhs;
residual(42) = params(27)*(exp(y(24))*exp(y(26))-exp(y(13))*exp(y(11))*params(28)*exp(y(39))-y(29)*T421*params(29))+y(25)*(1-params(27));
lhs =y(57);
rhs =params(66)*(exp(y(10))*exp(y(12))-exp(y(20))-y(29));
residual(43)= lhs-rhs;
lhs =exp(y(30));
rhs =params(17);
residual(44)= lhs-rhs;
lhs =exp(y(31));
rhs =params(17);
residual(45)= lhs-rhs;
lhs =params(3)+(y(65)-params(36))*(1-params(56));
rhs =params(31)*params(50)*(y(46)-params(46));
residual(46)= lhs-rhs;
lhs =params(3)+(y(64)-params(37))*(1-params(56));
rhs =params(50)*params(32)*(y(47)-params(47));
residual(47)= lhs-rhs;
residual(48) = y(70);
residual(49) = y(69);
residual(50) = exp(y(40))*y(65)*params(14)+y(42);
residual(51) = exp(y(41))*y(64)*params(14)+y(43);
lhs =exp(y(45));
rhs =exp(y(10))*exp(y(12))/exp(y(20));
residual(52)= lhs-rhs;
lhs =exp(y(44));
rhs =(exp(y(11))*exp(y(13))+y(29)*T421)/exp(y(24));
residual(53)= lhs-rhs;
lhs =y(46);
rhs =y(27)-y(19);
residual(54)= lhs-rhs;
lhs =y(47);
rhs =y(28)-y(18);
residual(55)= lhs-rhs;
lhs =exp(params(95))*y(48);
rhs =y(17)-y(29);
residual(56)= lhs-rhs;
lhs =y(59);
rhs =y(32)-y(40);
residual(57)= lhs-rhs;
lhs =y(60);
rhs =y(33)-y(41);
residual(58)= lhs-rhs;
residual(59) = y(49);
residual(60) = y(53);
residual(61) = y(61);
residual(62) = y(62);
lhs =y(56);
rhs =y(29)/exp(y(40));
residual(63)= lhs-rhs;
lhs =y(54);
rhs =(exp(y(40))-exp(y(32))-exp(y(7)))/exp(y(40));
residual(64)= lhs-rhs;
residual(65) = y(55);
lhs =y(38);
rhs =y(38)*params(79);
residual(66)= lhs-rhs;
lhs =y(39);
rhs =y(39)*params(80);
residual(67)= lhs-rhs;
lhs =y(34);
rhs =y(34)*params(76)+y(35)*params(83)+params(86)*x(1)+params(85)*x(2);
residual(68)= lhs-rhs;
lhs =y(35);
rhs =y(35)*params(77)+y(34)*params(82)+x(2)*params(87)+x(1)*params(84);
residual(69)= lhs-rhs;
lhs =y(36);
rhs =y(36)*params(78)+params(89)*x(4);
residual(70)= lhs-rhs;
lhs =y(37);
rhs =y(37)*params(78)+params(88)*x(5);
residual(71)= lhs-rhs;
lhs =y(63);
rhs =x(3);
residual(72)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(72, 72);

  %
  % Jacobian matrix
  %

T675 = getPowerDeriv(exp(y(8))+params(65)*y(51),1+params(25),1);
T686 = exp(y(8))*getPowerDeriv(exp(y(8)),1-params(14),1);
T696 = getPowerDeriv(exp(y(8))+params(65)*y(51),params(25),1);
T702 = getPowerDeriv(exp(y(9))+params(65)*y(52),1+params(25),1);
T713 = exp(y(9))*getPowerDeriv(exp(y(9)),1-params(14),1);
T723 = getPowerDeriv(exp(y(9))+params(65)*y(52),params(25),1);
T731 = (1-params(12))*(-(exp(y(10))*params(19)*exp(y(12))))/params(12);
T732 = exp(y(10))*exp(y(14))+T731;
T749 = (1-params(13))*(-(exp(y(11))*params(20)*exp(y(13))))/params(13);
T750 = exp(y(11))*exp(y(15))+T749;
T778 = (-(exp(y(14))*exp(y(12))*params(18)))/(exp(y(12))*params(18)*exp(y(12))*params(18));
T779 = params(22)*T778;
T793 = exp(y(12))*exp(y(36))*getPowerDeriv(exp(y(12))*exp(y(36)),params(14),1);
T795 = T340*T334*T793;
T818 = (-(exp(y(15))*exp(y(13))*params(18)))/(exp(y(13))*params(18)*exp(y(13))*params(18));
T819 = params(22)*T818;
T833 = exp(y(13))*exp(y(37))*getPowerDeriv(exp(y(13))*exp(y(37)),params(14),1);
T835 = T351*T347*T833;
T934 = params(66)*(1-params(12))*exp(y(20))/params(12);
  g1(1,3)=(-(params(63)*params(71)*params(1)));
  g1(1,4)=(-(params(64)*params(72)*(1-params(1))));
  g1(1,5)=1;
  g1(2,66)=1;
  g1(2,67)=(-(params(63)*params(71)*params(1)));
  g1(2,68)=(-(params(64)*params(72)*(1-params(1))));
  g1(3,3)=1;
  g1(3,7)=(-1);
  g1(3,8)=params(21)*exp(y(8))*T675/(1+params(25));
  g1(3,51)=(-((-(params(21)*params(65)*T675/(1+params(25))))-(1-params(65))));
  g1(4,4)=1;
  g1(4,6)=(-1);
  g1(4,9)=params(21)*exp(y(9))*T702/(1+params(25));
  g1(4,52)=(-((-(params(21)*params(65)*T702/(1+params(25))))-(1-params(65))));
  g1(5,7)=(-1);
  g1(5,8)=params(21)*exp(y(8))*getPowerDeriv(exp(y(8)),1+params(25),1)/(1+params(25));
  g1(5,67)=1;
  g1(6,6)=(-1);
  g1(6,9)=params(21)*exp(y(9))*getPowerDeriv(exp(y(9)),1+params(25),1)/(1+params(25));
  g1(6,68)=1;
  g1(7,51)=1;
  g1(7,65)=(-(params(61)+0.5*params(62)*2*(y(65)-params(36))));
  g1(8,52)=1;
  g1(8,64)=(-(params(61)+0.5*params(62)*2*(y(64)-params(37))));
  g1(9,19)=exp(y(19))*exp(y(30));
  g1(9,30)=exp(y(19))*exp(y(30));
  g1(10,18)=exp(y(18))*exp(y(31));
  g1(10,31)=exp(y(18))*exp(y(31));
  g1(11,6)=(-params(51));
  g1(11,7)=params(51);
  g1(11,17)=(1-params(51))*exp(y(30))*exp(y(18))*params(7)*exp(params(7)*(y(17)-params(94)));
  g1(11,18)=(1-params(51))*exp(y(30))*exp(y(18))*exp(params(7)*(y(17)-params(94)));
  g1(11,30)=(1-params(51))*exp(y(30))*exp(y(18))*exp(params(7)*(y(17)-params(94)));
  g1(11,63)=params(51)*params(59)*2*y(63);
  g1(12,7)=(-exp(y(7)));
  g1(12,10)=params(66)*(T732-exp(y(10))*params(19)*exp(y(12)));
  g1(12,12)=params(66)*(T731-exp(y(10))*params(19)*exp(y(12)));
  g1(12,14)=params(66)*exp(y(10))*exp(y(14));
  g1(12,17)=params(51)*params(66)*((-1)+exp(y(18)))+(1-params(51))*((-1)+exp(y(18)));
  g1(12,18)=params(51)*params(66)*exp(y(18))*y(17)+(1-params(51))*exp(y(18))*y(17);
  g1(12,19)=params(66)*exp(y(19))*y(57);
  g1(12,20)=T934;
  g1(12,30)=params(51)*(-(exp(y(30))*y(50)));
  g1(12,32)=(-exp(y(32)));
  g1(12,40)=exp(y(40))+params(66)*exp(y(40))*(y(65)-1)*params(14);
  g1(12,50)=params(51)*(1-exp(y(30)));
  g1(12,57)=params(66)*((-1)+exp(y(19)));
  g1(12,65)=params(66)*exp(y(40))*params(14);
  g1(13,10)=(-(params(66)*T732));
  g1(13,12)=(-(params(66)*T731));
  g1(13,14)=(-(params(66)*exp(y(10))*exp(y(14))));
  g1(13,17)=(-(params(51)*exp(y(18))*params(66)+exp(y(18))*(1-params(51))));
  g1(13,18)=(-(params(51)*params(66)*exp(y(18))*y(17)+(1-params(51))*exp(y(18))*y(17)));
  g1(13,19)=(-(params(66)*exp(y(19))*y(57)));
  g1(13,20)=(-T934);
  g1(13,32)=(-(params(66)*(-exp(y(32)))));
  g1(13,40)=(-exp(y(40)));
  g1(13,57)=(-(exp(y(19))*params(66)));
  g1(13,71)=1;
  g1(14,11)=(-(params(66)*T750));
  g1(14,13)=(-(params(66)*T749));
  g1(14,15)=(-(params(66)*exp(y(11))*exp(y(15))));
  g1(14,17)=(-(params(51)*params(66)*T206+(1-params(51))*T206));
  g1(14,18)=(-(params(51)*params(66)*y(17)*T206+(1-params(51))*y(17)*T206+params(66)*exp(y(18))*y(58)));
  g1(14,24)=(-(params(66)*(1-params(13))*exp(y(24))/params(13)));
  g1(14,33)=(-(params(66)*(-exp(y(33)))));
  g1(14,41)=(-exp(y(41)));
  g1(14,58)=(-(exp(y(18))*params(66)));
  g1(14,72)=1;
  g1(15,6)=T241*(-exp(y(6)));
  g1(15,7)=(-exp(y(7)));
  g1(15,10)=params(66)*(T732-exp(y(10))*params(19)*exp(y(12)));
  g1(15,11)=T241*params(66)*(T750-exp(y(11))*params(20)*exp(y(13)));
  g1(15,12)=params(66)*(T731-exp(y(10))*params(19)*exp(y(12)));
  g1(15,13)=T241*params(66)*(T749-exp(y(11))*params(20)*exp(y(13)));
  g1(15,14)=params(66)*exp(y(10))*exp(y(14));
  g1(15,15)=T241*params(66)*exp(y(11))*exp(y(15));
  g1(15,18)=T241*params(66)*exp(y(18))*y(58);
  g1(15,19)=params(66)*exp(y(19))*y(57);
  g1(15,20)=T934;
  g1(15,24)=T241*params(66)*(1-params(13))*exp(y(24))/params(13);
  g1(15,32)=(-exp(y(32)));
  g1(15,33)=T241*(-exp(y(33)));
  g1(15,40)=exp(y(40))+params(66)*exp(y(40))*(y(65)-1)*params(14);
  g1(15,41)=T241*(exp(y(41))+params(66)*exp(y(41))*params(14)*(y(64)-1));
  g1(15,57)=params(66)*((-1)+exp(y(19)));
  g1(15,58)=T241*params(66)*(exp(y(18))-1);
  g1(15,64)=T241*params(66)*params(14)*exp(y(41));
  g1(15,65)=params(66)*exp(y(40))*params(14);
  g1(16,1)=exp(y(1));
  g1(16,8)=(-(T271*T268*params(14)*exp(y(34))*T686));
  g1(16,12)=(-(params(14)*exp(y(34))*T264*T268*exp(y(12))*getPowerDeriv(exp(y(12)),params(14)-1,1)));
  g1(16,34)=(-(params(14)*exp(y(34))*T264*T268*T271));
  g1(16,36)=(-(T271*params(14)*exp(y(34))*T264*exp(y(36))*getPowerDeriv(exp(y(36)),params(14),1)));
  g1(17,2)=exp(y(2));
  g1(17,9)=(-(T285*T283*params(14)*exp(y(35))*T713));
  g1(17,13)=(-(params(14)*exp(y(35))*T279*T283*exp(y(13))*getPowerDeriv(exp(y(13)),params(14)-1,1)));
  g1(17,35)=(-(params(14)*exp(y(35))*T279*T283*T285));
  g1(17,37)=(-(T285*params(14)*exp(y(35))*T279*exp(y(37))*getPowerDeriv(exp(y(37)),params(14),1)));
  g1(18,1)=(-(exp(y(1))*(1-y(65))));
  g1(18,10)=exp(y(10))*exp(y(27))-exp(y(10))*exp(y(36))*(1-params(18));
  g1(18,12)=(-((1-params(23))*(T306*T779+T304*(-(exp(y(14))*exp(y(12))))/(exp(y(12))*exp(y(12)))*2*T305)/params(18)));
  g1(18,14)=(-((1-params(23))*(T306*params(22)*T302+T304*T305*2*T305)/params(18)));
  g1(18,27)=exp(y(10))*exp(y(27));
  g1(18,36)=(-(exp(y(10))*exp(y(36))*(1-params(18))));
  g1(18,65)=exp(y(1));
  g1(19,2)=(-(exp(y(2))*(1-y(64))));
  g1(19,11)=exp(y(11))*exp(y(28))-exp(y(11))*exp(y(37))*(1-params(18));
  g1(19,13)=(-((1-params(23))*(T325*T819+T323*(-(exp(y(15))*exp(y(13))))/(exp(y(13))*exp(y(13)))*2*T324)/params(18)));
  g1(19,15)=(-((1-params(23))*(T325*params(22)*T321+T323*T324*2*T324)/params(18)));
  g1(19,28)=exp(y(11))*exp(y(28));
  g1(19,37)=(-(exp(y(11))*exp(y(37))*(1-params(18))));
  g1(19,64)=exp(y(2));
  g1(20,7)=T337*exp(y(7))*getPowerDeriv(exp(y(7)),(-params(26)),1);
  g1(20,8)=T340*T336*exp(y(34))*(1-params(14))*exp(y(8))*getPowerDeriv(exp(y(8)),(-params(14)),1)-params(21)*exp(y(8))*T696;
  g1(20,12)=T795;
  g1(20,34)=T337*T340;
  g1(20,36)=T795;
  g1(20,51)=(-(params(21)*params(65)*T696));
  g1(21,6)=T350*exp(y(6))*getPowerDeriv(exp(y(6)),(-params(26)),1);
  g1(21,9)=T351*T349*(1-params(14))*exp(y(35))*exp(y(9))*getPowerDeriv(exp(y(9)),(-params(14)),1)-params(21)*exp(y(9))*T723;
  g1(21,13)=T835;
  g1(21,35)=T350*T351;
  g1(21,37)=T835;
  g1(21,52)=(-(params(21)*params(65)*T723));
  g1(22,12)=exp(y(12))-exp(y(12))*exp(y(36))*(1-params(18));
  g1(22,14)=(-exp(y(14)));
  g1(22,36)=(-(exp(y(12))*exp(y(36))*(1-params(18))));
  g1(23,13)=exp(y(13))-exp(y(13))*exp(y(37))*(1-params(18));
  g1(23,15)=(-exp(y(15)));
  g1(23,37)=(-(exp(y(13))*exp(y(37))*(1-params(18))));
  g1(24,10)=exp(y(10));
  g1(24,12)=(-((1-params(23))*T779));
  g1(24,14)=(-((1-params(23))*params(22)*T302));
  g1(25,11)=exp(y(11));
  g1(25,13)=(-((1-params(23))*T819));
  g1(25,15)=(-((1-params(23))*params(22)*T321));
  g1(26,12)=(-(exp(y(14))*(1-params(23))*T362*T778*2*T303));
  g1(26,14)=(-(T379+exp(y(14))*(1-params(23))*T362*T302*2*T303));
  g1(26,32)=exp(y(32));
  g1(27,13)=(-(exp(y(15))*(1-params(23))*T362*T818*2*T322));
  g1(27,15)=(-(T385+exp(y(15))*(1-params(23))*T362*T321*2*T322));
  g1(27,33)=exp(y(33));
  g1(28,17)=params(51);
  g1(28,50)=1-params(51);
  g1(29,8)=T336*exp(y(34))*T686;
  g1(29,12)=exp(y(34))*T264*T793;
  g1(29,34)=T336*exp(y(34))*T264;
  g1(29,36)=exp(y(34))*T264*T793;
  g1(29,40)=(-exp(y(40)));
  g1(30,9)=T349*exp(y(35))*T713;
  g1(30,13)=exp(y(35))*T279*T833;
  g1(30,35)=T349*exp(y(35))*T279;
  g1(30,37)=exp(y(35))*T279*T833;
  g1(30,41)=(-exp(y(41)));
  g1(31,16)=(-((1-params(38))*exp(y(16))/params(55)));
  g1(31,19)=(-(exp(y(19))*params(38)+(1-params(38))*(exp(y(19))*params(55)+(-exp(y(19))))/params(55)));
  g1(31,23)=exp(y(23));
  g1(32,29)=params(38)+(1-params(38))*(params(55)-1);
  g1(32,57)=(-(1-params(38)));
  g1(33,11)=(-(params(66)*exp(y(11))*exp(y(13))));
  g1(33,13)=(-(params(66)*exp(y(11))*exp(y(13))));
  g1(33,24)=(-(params(66)*(-exp(y(24)))));
  g1(33,29)=(-(params(66)*T421));
  g1(33,58)=1;
  g1(34,21)=(-(params(30)*exp(y(38))));
  g1(34,22)=(exp(y(27))-exp(y(23)))*exp(y(30))*params(27)*params(12)*exp(y(22));
  g1(34,23)=T435*(-exp(y(23)));
  g1(34,27)=exp(y(27))*T435;
  g1(34,30)=T435*(exp(y(27))-exp(y(23)));
  g1(34,38)=(-(y(21)*params(30)*exp(y(38))));
  g1(35,18)=T453*(-exp(y(18)));
  g1(35,25)=(-(params(28)*exp(y(39))));
  g1(35,26)=(exp(y(28))-exp(y(18)))*exp(y(31))*params(27)*params(13)*exp(y(26));
  g1(35,28)=exp(y(28))*T453;
  g1(35,31)=T453*(exp(y(28))-exp(y(18)));
  g1(35,39)=(-(params(28)*exp(y(39))*y(25)));
  g1(36,21)=(-exp(y(22)));
  g1(36,22)=exp(y(22))*(1-y(21))-exp(y(23))*exp(y(30))*params(27)*params(12)*exp(y(22));
  g1(36,23)=(-(exp(y(23))*T435));
  g1(36,30)=(-(exp(y(23))*T435));
  g1(37,18)=exp(y(18))*T453;
  g1(37,25)=exp(y(26));
  g1(37,26)=(-exp(y(26)))*(1-y(25))+exp(y(18))*exp(y(31))*params(27)*params(13)*exp(y(26));
  g1(37,31)=exp(y(18))*T453;
  g1(38,10)=params(27)*(-(exp(y(12))*exp(y(10))*params(30)*exp(y(38))));
  g1(38,12)=params(27)*(-(exp(y(12))*exp(y(10))*params(30)*exp(y(38))));
  g1(38,20)=params(27)*exp(y(20))*exp(y(22));
  g1(38,21)=1-params(27);
  g1(38,22)=params(27)*exp(y(20))*exp(y(22));
  g1(38,38)=params(27)*(-(exp(y(12))*exp(y(10))*params(30)*exp(y(38))));
  g1(39,10)=(-(params(66)*(exp(y(10))*params(19)*exp(y(12))+params(12)*exp(y(12))*exp(y(10))*exp(y(27)))));
  g1(39,12)=(-(params(66)*(exp(y(10))*params(19)*exp(y(12))+params(12)*exp(y(12))*exp(y(10))*exp(y(27)))));
  g1(39,20)=exp(y(20));
  g1(39,23)=(-(params(66)*params(12)*(-(exp(y(23))*(y(57)+y(29))))));
  g1(39,27)=(-(params(66)*params(12)*exp(y(12))*exp(y(10))*exp(y(27))));
  g1(39,29)=(-(params(66)*params(12)*(-exp(y(23)))));
  g1(39,57)=(-(params(66)*params(12)*(-exp(y(23)))));
  g1(40,11)=(-(params(66)*(exp(y(11))*params(20)*exp(y(13))+params(13)*exp(y(13))*exp(y(11))*exp(y(28)))));
  g1(40,13)=(-(params(66)*(exp(y(11))*params(20)*exp(y(13))+params(13)*exp(y(13))*exp(y(11))*exp(y(28)))));
  g1(40,16)=(-(params(66)*params(13)*exp(y(16))*y(29)*T421));
  g1(40,18)=(-(params(66)*params(13)*(-(exp(y(18))*y(58)))));
  g1(40,24)=exp(y(24));
  g1(40,28)=(-(params(66)*params(13)*exp(y(13))*exp(y(11))*exp(y(28))));
  g1(40,29)=(-(params(66)*params(13)*exp(y(16))*T421));
  g1(40,58)=(-(params(66)*params(13)*(-exp(y(18)))));
  g1(41,16)=exp(y(16))*T453;
  g1(41,18)=T453*(-exp(y(18)));
  g1(41,25)=(-(exp(y(39))*params(29)));
  g1(41,26)=(exp(y(16))-exp(y(18)))*exp(y(31))*params(27)*params(13)*exp(y(26));
  g1(41,31)=T453*(exp(y(16))-exp(y(18)));
  g1(41,39)=(-(y(25)*exp(y(39))*params(29)));
  g1(42,11)=params(27)*(-(exp(y(13))*exp(y(11))*params(28)*exp(y(39))));
  g1(42,13)=params(27)*(-(exp(y(13))*exp(y(11))*params(28)*exp(y(39))));
  g1(42,24)=params(27)*exp(y(24))*exp(y(26));
  g1(42,25)=1-params(27);
  g1(42,26)=params(27)*exp(y(24))*exp(y(26));
  g1(42,29)=params(27)*(-(T421*params(29)));
  g1(42,39)=params(27)*(-(exp(y(13))*exp(y(11))*params(28)*exp(y(39))));
  g1(43,10)=(-(params(66)*exp(y(10))*exp(y(12))));
  g1(43,12)=(-(params(66)*exp(y(10))*exp(y(12))));
  g1(43,20)=(-(params(66)*(-exp(y(20)))));
  g1(43,29)=params(66);
  g1(43,57)=1;
  g1(44,30)=exp(y(30));
  g1(45,31)=exp(y(31));
  g1(46,46)=(-(params(31)*params(50)));
  g1(46,65)=1-params(56);
  g1(47,47)=(-(params(50)*params(32)));
  g1(47,64)=1-params(56);
  g1(48,70)=1;
  g1(49,69)=1;
  g1(50,40)=exp(y(40))*y(65)*params(14);
  g1(50,42)=1;
  g1(50,65)=exp(y(40))*params(14);
  g1(51,41)=exp(y(41))*y(64)*params(14);
  g1(51,43)=1;
  g1(51,64)=params(14)*exp(y(41));
  g1(52,10)=(-(exp(y(10))*exp(y(12))/exp(y(20))));
  g1(52,12)=(-(exp(y(10))*exp(y(12))/exp(y(20))));
  g1(52,20)=(-((-(exp(y(20))*exp(y(10))*exp(y(12))))/(exp(y(20))*exp(y(20)))));
  g1(52,45)=exp(y(45));
  g1(53,11)=(-(exp(y(11))*exp(y(13))/exp(y(24))));
  g1(53,13)=(-(exp(y(11))*exp(y(13))/exp(y(24))));
  g1(53,24)=(-((-(exp(y(24))*(exp(y(11))*exp(y(13))+y(29)*T421)))/(exp(y(24))*exp(y(24)))));
  g1(53,29)=(-(T421/exp(y(24))));
  g1(53,44)=exp(y(44));
  g1(54,19)=1;
  g1(54,27)=(-1);
  g1(54,46)=1;
  g1(55,18)=1;
  g1(55,28)=(-1);
  g1(55,47)=1;
  g1(56,17)=(-1);
  g1(56,29)=1;
  g1(56,48)=exp(params(95));
  g1(57,32)=(-1);
  g1(57,40)=1;
  g1(57,59)=1;
  g1(58,33)=(-1);
  g1(58,41)=1;
  g1(58,60)=1;
  g1(59,49)=1;
  g1(60,53)=1;
  g1(61,61)=1;
  g1(62,62)=1;
  g1(63,29)=(-(1/exp(y(40))));
  g1(63,40)=(-((-(exp(y(40))*y(29)))/(exp(y(40))*exp(y(40)))));
  g1(63,56)=1;
  g1(64,7)=(-((-exp(y(7)))/exp(y(40))));
  g1(64,32)=(-((-exp(y(32)))/exp(y(40))));
  g1(64,40)=(-((exp(y(40))*exp(y(40))-exp(y(40))*(exp(y(40))-exp(y(32))-exp(y(7))))/(exp(y(40))*exp(y(40)))));
  g1(64,54)=1;
  g1(65,55)=1;
  g1(66,38)=1-params(79);
  g1(67,39)=1-params(80);
  g1(68,34)=1-params(76);
  g1(68,35)=(-params(83));
  g1(69,34)=(-params(82));
  g1(69,35)=1-params(77);
  g1(70,36)=1-params(78);
  g1(71,37)=1-params(78);
  g1(72,63)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],72,5184);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],72,373248);
end
end
end
end
