clc
clear
close all
addpath('utilities')
addpath('OPDSGE')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generate the optimal files
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0
    %Run these to generate the optimal files
    OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_SDLT 0 1 'tau_k_e' 'tau_k_c' 'uu_h' 'uu_f'
    
    %For the following, need to set up the GB_No_MaP.mod by setting the appropriate policy rule
    %OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_for_EME_only 0 0
    %OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_for_AE_only 0 0

    %NOTE!
    %After running, need to move the lm paramters in the new _steadystate file;
    %Then in the new mod file, add back the equation allowing complete market correction and the budget constraint.
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Recalculate Results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0
    
    %This is just to clear any global variables that may still persist as the remaining dynare calls are all with the noclear all option
    try dynare GB_No_MaP.mod
    end
    
    %This procedure sets up the regimes to run over
    Regime = Set_Up_IRF_Regimes;
    
    for Regime_ID = 1:numel(Regime)
        save('IRF_Results.mat', 'Regime', 'Regime_ID')

        %Clear all variables
        %close all
        clear
        clc

        %Reload loop variables
        load IRF_Results.mat
        disp(['Calculating for Regime ' num2str(Regime_ID) ': ' Regime(Regime_ID).Name])

        %Declare global variables
        global ffr BX_obj tx_smooth_k nash_param kappa_MPc kappa_MPe kappa_e  balbg cmk rams Nash verbose
        global tau_k_e_obj tau_k_c_obj uu_h kappa_cmk uu_f
        global k_D doloop psi_D
        global tx_alpha_k tx_beta_k tx_gamma_k optim_EME optim_AE Policy_Regime n


        %Set the parameter values of this run.
        tx_alpha_k = Regime(Regime_ID).tx_alpha_k;
        tx_gamma_k = Regime(Regime_ID).tx_gamma_k;
        nash_param = Regime(Regime_ID).nash_param;
        n = Regime(Regime_ID).n;


        %%1 is both countries optimizing; 2 is EME only; 3 is AE only
        Policy_Regime = Regime(Regime_ID).Policy_Regime;

        %Initial values of taxes depend on the Policy Regime
        %Also change the switches uu_h, uu_f, Optim_AE and Optim_EME
        switch Policy_Regime
            case 1 %Both countries
                fname='GB_No_MaP_optimal_SDLT';
                uu_h =1;
                uu_f  =1;
                optim_EME=1; 
                optim_AE=1;

                %Initial values of taxes
                tau_k_e_obj = 0;     
                tau_k_c_obj = 0;            
                starting_value=[tau_k_e_obj tau_k_c_obj];

            case 2 %EME only
                fname='GB_No_MaP_optimal_for_EME_only';
                uu_h =1;
                uu_f  =0;
                optim_EME=1; 
                optim_AE=0;

                %LR tax for Core country
                tau_k_c_obj =  0;       %Other country: No MaP
                %tau_k_c_obj =  -0.1625; %Other country: Nash
                %tau_k_c_obj =  -0.2715; %Other country: Coop

                %Initial value of taxes
                tau_k_e_obj = 0;
                starting_value=tau_k_e_obj;

            case 3 %AE only
                fname='GB_No_MaP_optimal_for_AE_only';
                uu_h =0;
                uu_f =1;
                optim_EME=0; 
                optim_AE=1;

                %LR tax for EME country
                tau_k_e_obj =  0;       %Other country: No MaP
                %tau_k_e_obj =  0.4456; %Other country: Nash
                %tau_k_e_obj =  -0.4411; %Other country: Coop (doesn't solve) (-0.37 is closest that solves)
                %tau_k_e_obj =  -0.37; %Other country: Coop (doesn't solve) (-0.37 is closest that solves)


                %Initial values of taxes
                tau_k_c_obj = 0;
                starting_value=tau_k_c_obj;


            case 4 %No MaP
                fname='GB_No_MaP';
                uu_h =1;
                uu_f  =1;
                optim_EME=1; 
                optim_AE=1;

                %Values of taxes
                tau_k_e_obj = 0;     
                tau_k_c_obj = 0;   
        end




        %Other global parameters

        tx_beta_k = 0; %Linear tax parameter, not used

        tx_smooth_k=0;
        k_D=Regime(Regime_ID).k_D;
        %psi_D=1;
        kappa_MPe=0;
        kappa_MPc=0;
        doloop=0;
        ffr= Regime(Regime_ID).ffr;
        kappa_cmk=0; % this is the risk-sharing constant place holder: see Corsetti-Lipinska-Lombardo
        rams=1;
        balbg=1; %%%%%% BALANCED BUDGET ALWAYS
        cmk=1;

        %Get parameter values
        param_GB

        %If not No Map
        if Policy_Regime ~=4
            %Run DYNARE
            try eval(['dynare ',fname,' noclearall'])
            end
            find_optimal_TAXES_steady_state
        end
        eval(['dynare ',fname,' noclearall'])


        %Do Complete Markets Correction        
        kappa_cmk=1;
        options_.qz_criterium = 1+1e-6;
        [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
        if info~=0
            error('')
        end

        pos_aux_sh=find_incell(M_.exo_names,'e_auxepsi');
        pos_AD2=find_incell(M_.endo_names,'AD');
        try Delta_mx=0.5*oo_.dr.CoLiLoghs2(oo_.dr.inv_order_var,:);
        catch
            disp('Failed to find solution')
            pause
        end
        vsh=M_.Sigma_e(:);
        pos_in_vec=pos_aux_sh+(M_.exo_nbr*(pos_aux_sh-1));
        nopos=setdiff([1:M_.exo_nbr*M_.exo_nbr],pos_in_vec);
        kappa_star=-(Delta_mx(pos_AD2,nopos)*vsh(nopos))/Delta_mx(pos_AD2,pos_in_vec);
        kappa_cmk=kappa_star/betta;

        %Resolve 
        [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
        if info~=0
            error('')
        end

        %Get IRFs
        global options_
        options_.irf=30;
        options_.order = 1;
        if 0
            %Run 2nd order IRFs
            options_.order = 2;
            options_.replic = 100;
            options_.pruning = 1;
        end
        options_.periods = 0;
        stoch_simul('');
        
        %Calculate Conditional Means
        cond_mom_dyn4(0,0,6000)

        %Save the results to be used as a comparison      
        save oo_opt.mat oo_ M_ -MAT



        %Calculate the conditional means wrt the Run_ID=1 regime unconditional means
        cond_mom_dyn4(1,0,6000)

        
        %Save IRFs
        if 0
            %Save all IRFs (large file size)
            Regime(Regime_ID).irfs = oo_.irfs;
        else
            %Only save specific irfs
            ShockNames = {'e_Ac','e_Ae','e_xic','e_xie'};
            VarsToPrint = {'tau_k_c', 'Yc',  'Itot_c', 'spread_c', 'tau_k_e',  'Ye', 'Itot_e', 'spread_e'};
            for ss=1:numel(ShockNames)
                for vv=1:numel(VarsToPrint)
                    Regime(Regime_ID).irfs.([VarsToPrint{vv} '_' ShockNames{ss}]) = oo_.irfs.([VarsToPrint{vv} '_' ShockNames{ss}]);
                end
            end
            
        end

        
        %Save results
        save('IRF_Results.mat', 'Regime', 'Regime_ID')

    end
end




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Process Results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc


load IRF_Results.mat


set(0, 'defaultTextInterpreter', 'latex')
set(0, 'defaultlegendinterpreter', 'latex')

if 0
    %Optimal taxes
    for Regime_ID = 1:numel(Regime)
        Taxes(Regime_ID, :) = Regime(Regime_ID).Taxes;
        Names{Regime_ID} = [num2str(Regime_ID)  ': ' Regime(Regime_ID).Name];
        Util_Res(Regime_ID, :) = Regime(Regime_ID).Utils';    
    end
    disp(array2table([round(Taxes,2) round(Util_Res, 4)], 'VariableNames', {'tau_k_e', 'tau_k_c', 'Util', 'Util_no_tax', 'UE', 'UE_no_tax', 'UC', 'UC_no_tax'}, 'RowNames', Names))
    disp(' ')
end

%Generate IRFs

FigureNames = {'IRBC', 'IRBC_FF_No_MaP', 'FF_kD_1', 'FF_kD_0p5', 'FF_kD_0'};
ShockNames = {'e_Ac','e_Ae','e_xic','e_xie'};
VarsToPrint = {'tau_k_c', 'Yc',  'Itot_c', 'spread_c', 'tau_k_e',  'Ye', 'Itot_e', 'spread_e'};
Titles = {'Tax on capital AE', 'GDP AE',   'Investment AE', 'Spread AE',  'Tax on capital EME',  'GDP EME', 'Investment EME', 'Spread EME'};
Style = {'k:', 'b', 'r--'};


nnn=0; %Counter
for fig_loop=1:numel(FigureNames)

    %These are the different figure comparisons
    switch fig_loop
        case 1
            %IRBC, n=1/2 (No MaP, Nash, Coop)
            RegimesToPrint = 1:3;
            VarsInFig = [1 2 3 5 6 7]; %Skip spreads
            Cols = 3;
            RebaseRegime = 1; %No MaP %Only relevant for plotting in levesl. Put empty if not rebasing
        case 2 
            %No MaP (IRBC, k_D=1, n=1/2;        FF, k_D = 1, n=1/2;         FF, k_D = 0, n=1/2))
            RegimesToPrint = [1 4 7];
            VarsInFig = [2 3 4 6 7 8]; %Skip taxes
            Cols = 3;
            RebaseRegime = 1; %IRBC %Only relevant for plotting in levels. Put empty if not rebasing
        case 3
            %FF (k_D=1, n=1/2), No Map, Nash, Coop
            RegimesToPrint = 4:6;
            VarsInFig = 1:numel(VarsToPrint);
            Cols = 4;
            RebaseRegime = 4; %No MaP %Only relevant for plotting in levels. Put empty if not rebasing
        case 4
            %FF, Asym (k_D=0.5, n=1/2), No Map, Nash, Coop
            RegimesToPrint = 7:9;
            VarsInFig = 1:numel(VarsToPrint);
            Cols = 4;
            RebaseRegime = 7; %No MaP %Only relevant for plotting in levels. Put empty if not rebasing
        case 5
            %FF, Greater Asym (k_D=0, n=1/2), No Map, Nash, Coop
            RegimesToPrint = 10:12;
            VarsInFig = 1:numel(VarsToPrint);
            Cols = 4;
            RebaseRegime = 10; %No MaP %Only relevant for plotting in levesl. Put empty if not rebasing
    end

    %clearvars Plot_pp
    for sss = 1:numel(ShockNames)
        nnn=nnn+1;


        %Deviations
        FigName = [FigureNames{fig_loop} '_' ShockNames{sss} ];


        %Create new figures
        f(nnn) = figure('Name', FigName);
        clearvars Plot_pp

        for rrr=1:numel(RegimesToPrint)

            ppp=0;
            clearvars ylims
            for vvv=VarsInFig
                ppp=ppp+1;
                figure(f(nnn))
                sp(ppp) = subplot(2, Cols, ppp);


                %Deviations
                %Get the IRF data, each column is a time period, each row is a variable, 3rd dimension specifies the regime, 4th dimension is the shock
                tmpData = eval(['Regime(' num2str(RegimesToPrint(rrr)) ').irfs.' VarsToPrint{vvv} '_' ShockNames{sss}])*100;



                tmpData(abs(tmpData)<1e-10) = 0; %Replace tiny values with 0
                PlotData(vvv, :, sss, rrr) = tmpData;

                tmpPlot = plot(1:size(PlotData, 2), PlotData(vvv, :, sss, rrr), Style{rrr});
                if ppp==1 %Save fot legend
                    Plot_pp(rrr)=tmpPlot;
                end
                hold on

                %Plot markers for No MaP
                if rrr==1
                    step = 3;
                    tmpPlot = scatter(1:step:size(PlotData, 2), tmpData(1:step:end), [], 'k');
                    if ppp==1 %Save fot legend
                        Plot_pp(rrr) = tmpPlot;
                    end
                end

                ylims(ppp, :) = ylim;

                title(Titles{vvv})
                if ppp==1 
                    %subplot(sp(ppp));
                    if fig_loop==2
                        legend(Plot_pp, 'IRBC', 'Symmetric FF, $k_D=1$', 'Asymmetric FF, $k_D=0$', 'Location', 'best')
                    else
                        legend(Plot_pp, 'No MaP', 'Cooperation', 'Nash', 'Location', 'best')
                    end
                end
            end
        end

        %Set each column to have the same ylimits
        for eee=1:ppp/2
            set(sp(eee),   'ylim', [min(ylims(eee,1), ylims(eee+ppp/2,1)) max(ylims(eee,2), ylims(eee+ppp/2,2))*1.1])
            set(sp(eee+ppp/2), 'ylim', [min(ylims(eee,1), ylims(eee+ppp/2,1)) max(ylims(eee,2), ylims(eee+ppp/2,2))*1.1])
        end
    end    
end

for ff=1:numel(f)
    %Increase font size
    %supersizeme(f(ff), 1.5)

    %Maximize figure
    pos = get(0,'Screensize');
    %pos(2) = pos(2) - 10; %Move figure down
    set(f(ff), 'Position', pos); 



    mkdir('figures')
    SaveAddress = 'figures';
    saveas(f(ff), [SaveAddress '\' f(ff).Name '.jpg'])

    set(f(ff), 'PaperOrientation','landscape');
    print(f(ff),'-dpdf','-fillpage', [SaveAddress '\' f(ff).Name '.pdf'])
end


close all



