clc
clear
close all
addpath('utilities')
addpath('OPDSGE')
set(0, 'defaultTextInterpreter', 'latex')
set(0, 'defaultlegendinterpreter', 'latex') 


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generate the optimal files
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0
    %Run these to generate the optimal files
    %OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_SDLT 0 1 'tau_k_e' 'tau_k_c' 'uu_h' 'uu_f'
    
    %For the following, need to set up the GB_No_MaP.mod by setting the appropriate policy rule
    %OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_for_EME_only 0 0
    OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_for_AE_only 0 0

    %NOTE!
    %After running, need to move the lm paramters in the new _steadystate file;
    %Then in the new mod file, add back the equation allowing complete market correction and the budget constraint.
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Recalculate Results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0
    %This procedure sets up the regimes to run over
    [Regime, tau_k_e_Tries, tau_k_c_Tries] = Set_Up_Spillover_Regimes;
    
    for Regime_ID = 1:numel(tau_k_e_Tries)*numel(tau_k_c_Tries)
        save('Spillovers.mat', 'Regime', 'Regime_ID', 'tau_k_e_Tries', 'tau_k_c_Tries')

        %Clear all variables
        %close all
        clear
        clc

        %Reload loop variables
        load Spillovers.mat
        disp(['Calculating for Regime ' num2str(Regime_ID) ': ' Regime(Regime_ID).Name])


    

        %Declare global variables
        global ffr BX_obj tx_smooth_k nash_param kappa_MPc kappa_MPe kappa_e  balbg cmk rams Nash verbose
        global tau_k_e_obj tau_k_c_obj uu_h kappa_cmk uu_f
        global k_D doloop psi_D
        global tx_alpha_k tx_beta_k tx_gamma_k optim_EME optim_AE Policy_Regime n


        %Set the parameter values of this run.
        tx_alpha_k = Regime(Regime_ID).tx_alpha_k;
        tx_gamma_k = Regime(Regime_ID).tx_gamma_k;
        nash_param = Regime(Regime_ID).nash_param;
        n=Regime(Regime_ID).n;

        %%1 is both countries optimizing; 2 is EME only; 3 is AE only
        Policy_Regime = Regime(Regime_ID).Policy_Regime;

        %Initial values of taxes depend on the Policy Regime
        %Also change the switches uu_h, uu_f, Optim_AE and Optim_EME
        switch Policy_Regime
            case 1 %Both countries
                fname='GB_No_MaP_optimal_SDLT';
                uu_h =1;
                uu_f  =1;
                optim_EME=1; 
                optim_AE=1;

                %Initial values of taxes
                tau_k_e_obj = 0;     
                tau_k_c_obj = 0;            
                starting_value=[tau_k_e_obj tau_k_c_obj];

            case 2 %EME only
                fname='GB_No_MaP_optimal_for_EME_only';
                uu_h =1;
                uu_f  =0;
                optim_EME=1; 
                optim_AE=0;

                %LR tax for Core country
                tau_k_c_obj =  0;       %Other country: No MaP
                %tau_k_c_obj =  -0.1625; %Other country: Nash
                %tau_k_c_obj =  -0.2715; %Other country: Coop

                %Initial value of taxes
                tau_k_e_obj = 0;
                starting_value=tau_k_e_obj;

            case 3 %AE only
                fname='GB_No_MaP_optimal_for_AE_only';
                uu_h =0;
                uu_f =1;
                optim_EME=0; 
                optim_AE=1;

                %LR tax for EME country
                tau_k_e_obj =  0;       %Other country: No MaP
                %tau_k_e_obj =  0.4456; %Other country: Nash
                %tau_k_e_obj =  -0.4411; %Other country: Coop (doesn't solve) (-0.37 is closest that solves)
                %tau_k_e_obj =  -0.37; %Other country: Coop (doesn't solve) (-0.37 is closest that solves)


                %Initial values of taxes
                tau_k_c_obj = 0;
                starting_value=tau_k_c_obj;


            case 4 %No MaP
                fname='GB_No_MaP';
                uu_h =1;
                uu_f  =1;
                optim_EME=1; 
                optim_AE=1;

                %Values of taxes
                tau_k_e_obj = Regime(Regime_ID).tau_k_e;     
                tau_k_c_obj = Regime(Regime_ID).tau_k_c;  
        end




        %Other global parameters

        tx_beta_k = 0; %Linear tax parameter, not used

        tx_smooth_k=0;
        k_D=Regime(Regime_ID).k_D;
        %psi_D=1;
        kappa_MPe=0;
        kappa_MPc=0;
        doloop=0;
        ffr=1;
        kappa_cmk=0; % this is the risk-sharing constant place holder: see Corsetti-Lipinska-Lombardo
        rams=1;
        balbg=1; %%%%%% BALANCED BUDGET ALWAYS
        cmk=1;

        %Get parameter values
        param_GB

        %If not No Map
        if Policy_Regime ~=4
            %Run DYNARE
            try eval(['dynare ',fname,' noclearall'])
            end
            find_optimal_TAXES_steady_state
        end
        eval(['dynare ',fname,' noclearall'])


        %Do Complete Markets Correction        
        kappa_cmk=1;
        options_.qz_criterium = 1+1e-6;
        %options_.dynatol.f = 1e-4;
        [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
        if info~=0
            error('')
        end

        pos_aux_sh=find_incell(M_.exo_names,'e_auxepsi');
        pos_AD2=find_incell(M_.endo_names,'AD');
        try Delta_mx=0.5*oo_.dr.CoLiLoghs2(oo_.dr.inv_order_var,:);
        catch
            disp('Failed to find solution')
            continue
        end
        vsh=M_.Sigma_e(:);
        pos_in_vec=pos_aux_sh+(M_.exo_nbr*(pos_aux_sh-1));
        nopos=setdiff([1:M_.exo_nbr*M_.exo_nbr],pos_in_vec);
        kappa_star=-(Delta_mx(pos_AD2,nopos)*vsh(nopos))/Delta_mx(pos_AD2,pos_in_vec);
        kappa_cmk=kappa_star/betta;

        %Resolve 
        [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
        if info~=0
            error('')
        end

        %Calculate Conditional Means
        cond_mom_dyn4(0,0,6000)

        %If the Base_Regime property is the same as the Regime_ID, save the results to be used as a comparison
        %This is the No MaP regime which is used as the comparison
        if Regime(Regime_ID).Base_Regime==Regime_ID                    
            save oo_opt.mat oo_ M_ -MAT
        end



        %Calculate the conditional means wrt the Run_ID=1 regime unconditional means
        cond_mom_dyn4(1,0,6000)


        %Save results
        
        if Regime(Regime_ID).Base_Regime==Regime_ID 
            %If this regime is a Base Regime, store the details
            %Regime(Regime_ID).oo_ = oo_;
            %Regime(Regime_ID).M_ = M_;
        end
        %Regime(Regime_ID).M_ = M_;
        %Regime(Regime_ID).oo_ = oo_;
        %Regime(Regime_ID).SS = oo_.steady_state;
        %Regime(Regime_ID).Uncond_Means = oo_.mean;
        %Regime(Regime_ID).Cond_Means = (oo_.mean_disc*(1-nbeta) + oo_.steady_state); 
        %Regime(Regime_ID).Stds = sqrt(diag(oo_.var));
        Regime(Regime_ID).Taxes = [tau_k_e_obj tau_k_c_obj];

     	%Get tax correlations
        Pos_tau_k_e = find_incell(M_.endo_names, 'tau_k_e');
        Pos_tau_k_c = find_incell(M_.endo_names, 'tau_k_c');
        Pos_Delta_tau_k_e = find_incell(M_.endo_names, 'Delta_tau_k_e');
        Pos_Delta_tau_k_c = find_incell(M_.endo_names, 'Delta_tau_k_c');
        %Regime(Regime_ID).TaxCorr = oo_.var(Pos_tau_k_e, Pos_tau_k_c)/sqrt(oo_.var(Pos_tau_k_e, Pos_tau_k_e)*oo_.var(Pos_tau_k_c, Pos_tau_k_c));
        %Regime(Regime_ID).DeltaTaxCorr = oo_.var(Pos_Delta_tau_k_e, Pos_Delta_tau_k_c)/sqrt(oo_.var(Pos_Delta_tau_k_e, Pos_Delta_tau_k_e)*oo_.var(Pos_Delta_tau_k_c, Pos_Delta_tau_k_c));

        %Get utility and coefficient of variation for specific variables
        %Note that no_pen refers to without the tax aversion penalty NOT the timeless penalty
        Vars_to_Fetch = {'Util', 'Util_no_pen', 'UE', 'UE_no_pen', 'UC', 'UC_no_pen', 'Ce','Cc', 'He', 'Hc', 'spread_e', 'spread_c', 'DGDP_e', 'DGDP_c'};
        Pos=zeros(size(Vars_to_Fetch));
        for kkk = 1:numel(Vars_to_Fetch)
            Pos(kkk) = find_incell(M_.endo_names, Vars_to_Fetch{kkk});
        end

        %Timeless penalty currently unused
        TimelessPenalty = 0;

        
        %The Pos variable references to the positions of the following variables
        %'Util', 'Util_no_pen', 'UE', 'UE_no_pen', 'UC', 'UC_no_pen', 'Ce','Cc', 'He', 'Hc', 'spread_e', 'spread_c', 'Delta_Ye', 'Delta_Yc'

        
        %Welfare
        %This takes into account the timeless penalty                     
        Cond_Means = (oo_.mean_disc*(1-nbeta) + oo_.steady_state); 
        Regime(Regime_ID).Utils = Cond_Means(Pos(1:6))+TimelessPenalty;

        
        %For the unilateral regimes, the Util variable only considers EME or AE welfare so needs to be re-calculated to consider global welfare
        if Policy_Regime == 2 || Policy_Regime ==3
            if Regime(Regime_ID).TimelessPenalty ==0
                Regime(Regime_ID).Utils(1:2) = n.*Cond_Means(Pos(3:4)) + (1-n).*Cond_Means(Pos(5:6)) ;            
            else
                Regime(Regime_ID).Utils(1:2) = n.*Cond_Means(Pos(3:4)) + (1-n).*Cond_Means(Pos(5:6)) + TimelessPenalty(1:2);            
            end
        end

        
        %First and second moments
        %These do not take into account the timeless penalty as it cannot be decomposed
        %Regime(Regime_ID).CoefVars       = Regime(Regime_ID).Stds(Pos(7:end))./Regime(Regime_ID).Cond_Means(Pos(7:end));
        %Regime(Regime_ID).CondMeanVars   = Regime(Regime_ID).Cond_Means(Pos(7:end));
        %Regime(Regime_ID).StdsVars       = Regime(Regime_ID).Stds(Pos(7:end));

        %Save results
        save('Spillovers.mat', 'Regime', 'Regime_ID', 'tau_k_e_Tries', 'tau_k_c_Tries')

    end
end




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Process Results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
load Spillovers.mat

%Extract results
Regime_ID=1; %Ignore the first regime as this is the base regime
for ccc = 1:numel(tau_k_c_Tries)
    for eee = 1:numel(tau_k_e_Tries)
        Regime_ID=Regime_ID+1;
        try Taxes(ccc, eee, :) = Regime(Regime_ID).Taxes;
        catch
            Taxes(ccc, eee, :) = nan(1, 2);
            UtilVar_Res(ccc, eee, :) = nan(1,6);    
            %Stds_Res(ccc, eee, :)  = nan(1,8);
            %Means_Res(ccc, eee, :)  = nan(1,8);
            %TaxCorr(ccc, eee) = nan(1,1);
            continue            
        end
        Names{ccc, eee} = [num2str(Regime_ID)  ': ' Regime(Regime_ID).Name];
        UtilVar_Res(ccc, eee, :) = Regime(Regime_ID).Utils';
        %Stds_Res(ccc, eee, :)  = Regime(Regime_ID).StdsVars;
        %Means_Res(ccc, eee, :)  = Regime(Regime_ID).CondMeanVars;
        %TaxCorr(ccc, eee) = Regime(Regime_ID).DeltaTaxCorr;
    end
end

set(0, 'defaultTextInterpreter', 'latex')
set(0, 'defaultlegendinterpreter', 'latex')




%E C
if 0
    %Without financial frictions
    suffix='_IRBC';
    Coop_Taxes = [0 0];
    Nash_Taxes = [0.2146 0.2146];
else
    %With financial frictions
    suffix='';
    Coop_Taxes = [-0.1816 -0.1816];
    Nash_Taxes = [0.0692 0.0692];
end
%Get taxes that are closest to the values I tried
Coop_Taxes_Approx = [find(abs(tau_k_e_Tries-Coop_Taxes(1))==min(abs(tau_k_e_Tries-Coop_Taxes(1)))) find(abs(tau_k_c_Tries-Coop_Taxes(2))==min(abs(tau_k_c_Tries-Coop_Taxes(2))))];
Nash_Taxes_Approx = [find(abs(tau_k_e_Tries-Nash_Taxes(1))==min(abs(tau_k_e_Tries-Nash_Taxes(1)))) find(abs(tau_k_c_Tries-Nash_Taxes(2))==min(abs(tau_k_c_Tries-Nash_Taxes(2))))];


%EME
optima_1 = UtilVar_Res(:,:,3)==max(UtilVar_Res(:,:,3), [], 1); %Maximize over columns

%Core
optima_2 = UtilVar_Res(:,:,5)==max(UtilVar_Res(:,:,5), [], 2); %Maximize over rows

NashEquilibria = and(optima_1==optima_2, optima_1==1);

tmp_e = Taxes(:,:,1);
tmp_c = Taxes(:,:,2);
Nash_2_Taxes = [tmp_e(NashEquilibria) tmp_c(NashEquilibria)];



%Figure counter
fff=0;

%Contour plot

fff=fff+1;
f(fff) = figure('Name', ['Contour' suffix]);

%%
titletext = {'Global welfare', 'Periphery welfare', 'Core welfare'};
Util_Row = [1 3 5];

Range_e = find(tau_k_e_Tries==-0.5):find(tau_k_e_Tries==0.5);
Range_c = find(tau_k_c_Tries==-0.5):find(tau_k_c_Tries==0.5);
%%

for sss=1:3
    sp(sss) = subplot(1,3,sss);
    [c,h]=contour(tau_k_e_Tries(Range_e), tau_k_c_Tries(Range_c), UtilVar_Res(Range_c,Range_e,Util_Row(sss)));
    
    %Add extra levels at the top 
    if sss==1
        AddContours = round(linspace(h.LevelList(end), max(max(UtilVar_Res(Range_c,Range_e,Util_Row(sss)))), 7),3);
        h.LevelList=[h.LevelList AddContours ];  
        [c,h]=contour(tau_k_e_Tries(Range_e), tau_k_c_Tries(Range_c), UtilVar_Res(Range_c,Range_e,Util_Row(sss)), h.LevelList);
    end
    
    clabel(c, h, 'LabelSpacing', 1000);     
    
    clims = caxis;
    caxis([min(min(UtilVar_Res(Range_c,Range_e,Util_Row(sss)))) max(max(UtilVar_Res(Range_c,Range_e,Util_Row(sss))))])
    hold on
    plot3(Coop_Taxes(1), Coop_Taxes(2), UtilVar_Res(Coop_Taxes_Approx(2),Coop_Taxes_Approx(1),Util_Row(sss)), 'gs', 'MarkerSize', 20, 'MarkerFaceColor', 'g')
    plot3(Nash_Taxes(1), Nash_Taxes(2), UtilVar_Res(Nash_Taxes_Approx(2),Nash_Taxes_Approx(1),Util_Row(sss)), 'ro', 'MarkerSize', 20, 'MarkerFaceColor', 'r')
    %plot3(Nash_2_Taxes(1), Nash_2_Taxes(2), UtilVar_Res(tau_k_c_Tries==Nash_2_Taxes(2),tau_k_e_Tries==Nash_2_Taxes(1),1), 'k^', 'MarkerSize', 20, 'MarkerFaceColor', 'k')
    ylabel('Core tax, $\tau_k^c$')
    xlabel('Periphery tax, $\tau_k^e$')
    
    title(titletext{sss})
end



%%

for ff=1:numel(f)
    %Maximize figure
    pos = get(0,'Screensize');
    %pos(2) = pos(2) - 10; %Move figure down
    set(f(ff), 'Position', pos); 

  
    mkdir('figures')
    SaveAddress = 'figures';
    saveas(f(ff), [SaveAddress '\' f(ff).Name '.jpg'])
    saveas(f(ff), [SaveAddress '\' f(ff).Name '.fig'])
    
    set(f(ff), 'PaperOrientation','landscape');
    print(f(ff),'-dpdf','-fillpage', [SaveAddress '\' f(ff).Name '.pdf'])
end

close all