clc
clear
close all
addpath('utilities')
addpath('OPDSGE')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Generate the optimal files
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0
    %Run these to generate the optimal files
    OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_SDLT 0 1 'tau_k_e' 'tau_k_c' 'uu_h' 'uu_f'
    %clc
    %For the following, need to set up the GB_No_MaP.mod by setting the appropriate policy rule
    %OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_for_EME_only 0 0
    %OPDSGE GB_No_MaP Util Welf poly ramsey _ss optimal_for_AE_only 0 0

    %NOTE!
    %After running, need to move the lm paramters in the new _steadystate file;
    %Then in the new mod file, add back the equation allowing complete market correction and the budget constraint.
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Recalculate Results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if 0
    %This procedure sets up the regimes to run over
    [Regime, alpha_k_Runs] = Set_Up_Table_Regimes;
    
    for Regime_ID = 1:numel(Regime)
        save('Table_Results.mat', 'Regime', 'Regime_ID', 'alpha_k_Runs')

        %Clear all variables
        %close all
        clear
        clc

        %Reload loop variables
        load Table_Results.mat
        disp(['Calculating for Regime ' num2str(Regime_ID) ': ' Regime(Regime_ID).Name])

        
        
        %This is used for calculating the conditional means
        %If this regime is not a Base Regime, make sure that oo_opt.mat is saved with the oo_ and M_ structures associated with
        %the Base_Regime identified in the Base_Regime property for this particular regime.
        if Regime(Regime_ID).Base_Regime~=Regime_ID 
            Base_Regime_ID = Regime(Regime_ID).Base_Regime;
            oo_ = Regime(Base_Regime_ID).oo_;
            M_ = Regime(Base_Regime_ID).M_;
            save oo_opt.mat oo_ M_ -MAT
            clearvars oo_ M_
        end

        %Declare global variables
        global ffr BX_obj tx_smooth_k nash_param kappa_MPc kappa_MPe kappa_e  balbg cmk rams Nash verbose
        global tau_k_e_obj tau_k_c_obj uu_h kappa_cmk uu_f
        global k_D doloop psi_D
        global tx_alpha_k tx_beta_k tx_gamma_k optim_EME optim_AE Policy_Regime n


        %Set the parameter values of this run.
        tx_alpha_k = Regime(Regime_ID).tx_alpha_k;
        tx_gamma_k = Regime(Regime_ID).tx_gamma_k;
        nash_param = Regime(Regime_ID).nash_param;
        n = Regime(Regime_ID).n;


        %%1 is both countries optimizing; 2 is EME only; 3 is AE only   
        Policy_Regime = Regime(Regime_ID).Policy_Regime;

        %Initial values of taxes depend on the Policy Regime
        %Also change the switches uu_h, uu_f, Optim_AE and Optim_EME
        switch Policy_Regime
            case 1 %Both countries
                fname='GB_No_MaP_optimal_SDLT';
                uu_h =1;
                uu_f  =1;
                optim_EME=1; 
                optim_AE=1;

                %Initial values of taxes
                tau_k_e_obj = 0.5;     
                tau_k_c_obj = 0.5;            
                starting_value=[tau_k_e_obj tau_k_c_obj];

            case 2 %EME only
                fname='GB_No_MaP_optimal_for_EME_only';
                uu_h =1;
                uu_f  =0;
                optim_EME=1; 
                optim_AE=0;

                %LR tax for Core country
                tau_k_c_obj =  0;       %Other country: No MaP
                %tau_k_c_obj =  -0.1625; %Other country: Nash
                %tau_k_c_obj =  -0.2715; %Other country: Coop

                %Initial value of taxes
                tau_k_e_obj = 0;
                starting_value=tau_k_e_obj;

            case 3 %AE only
                fname='GB_No_MaP_optimal_for_AE_only';
                uu_h =0;
                uu_f =1;
                optim_EME=0; 
                optim_AE=1;

                %LR tax for EME country
                tau_k_e_obj =  0;       %Other country: No MaP
                %tau_k_e_obj =  0.4456; %Other country: Nash
                %tau_k_e_obj =  -0.4411; %Other country: Coop (doesn't solve) (-0.37 is closest that solves)
                %tau_k_e_obj =  -0.37; %Other country: Coop (doesn't solve) (-0.37 is closest that solves)


                %Initial values of taxes
                tau_k_c_obj = 0;
                starting_value=tau_k_c_obj;


            case 4 %No MaP
                fname='GB_No_MaP';
                uu_h =1;
                uu_f  =1;
                optim_EME=1; 
                optim_AE=1;

                %Values of taxes
                tau_k_e_obj = 0;     
                tau_k_c_obj = 0;   
        end




        %Other global parameters

        tx_beta_k = 0; %Linear tax parameter, not used

        tx_smooth_k=0;
        k_D=Regime(Regime_ID).k_D;
        %psi_D=1/(1-k_D); %No need to set this as it gets overwritten later
        kappa_MPe=0;
        kappa_MPc=0;
        doloop=0;
        ffr=Regime(Regime_ID).ffr;
        kappa_cmk=0; % this is the risk-sharing constant place holder: see Corsetti-Lipinska-Lombardo
        rams=1;
        balbg=1; %%%%%% BALANCED BUDGET ALWAYS
        cmk=1;

        %Get parameter values
        param_GB

        %If not No Map
        if Policy_Regime ~=4
            %Run DYNARE
            try eval(['dynare ',fname,' noclearall'])
            end
            find_optimal_TAXES_steady_state
        end
        eval(['dynare ',fname,' noclearall'])


        %Do Complete Markets Correction        
        kappa_cmk=1;
        options_.qz_criterium = 1+1e-6;
        [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
        if info~=0
            error('')
        end

        pos_aux_sh=find_incell(M_.exo_names,'e_auxepsi');
        pos_AD2=find_incell(M_.endo_names,'AD');
        try Delta_mx=0.5*oo_.dr.CoLiLoghs2(oo_.dr.inv_order_var,:);
        catch
            disp('Failed to find solution')
            pause
        end
        vsh=M_.Sigma_e(:);
        pos_in_vec=pos_aux_sh+(M_.exo_nbr*(pos_aux_sh-1));
        nopos=setdiff([1:M_.exo_nbr*M_.exo_nbr],pos_in_vec);
        kappa_star=-(Delta_mx(pos_AD2,nopos)*vsh(nopos))/Delta_mx(pos_AD2,pos_in_vec);
        kappa_cmk=kappa_star/betta;

        %Resolve 
        [oo_.dr,info,M_,options_,oo_] = resol(0,M_,options_,oo_);
        if info~=0
            error('')
        end
        
        %Calculate Conditional Means
        cond_mom_dyn4(0,0,6000)

        %If the Base_Regime property is the same as the Regime_ID, save the results to be used as a comparison
        %This is the No MaP regime which is used as the comparison
        if Regime(Regime_ID).Base_Regime==Regime_ID                    
            save oo_opt.mat oo_ M_ -MAT
        end



        %Calculate the conditional means wrt the Run_ID=1 regime unconditional means
        cond_mom_dyn4(1,0,6000)


        

        
        %Save results
        if Regime(Regime_ID).Base_Regime==Regime_ID 
            %If this regime is a Base Regime, store the details
            Regime(Regime_ID).oo_ = oo_;
            Regime(Regime_ID).M_ = M_;
        end
        
        SS = oo_.steady_state;
        
        Vars = {'spread_e','spread_c', 'Leverage_e', 'Leverage_c', 'I_GDP_e', 'I_GDP_c'};
        for vvv=1:numel(Vars)
            Regime(Regime_ID).SS(vvv) = SS(find_incell(M_.endo_names, Vars{vvv}));
        end
        
        
        Uncond_Means = oo_.mean;
        Cond_Means = (oo_.mean_disc*(1-nbeta) + oo_.steady_state );%
        
        
        
        Stds = sqrt(diag(oo_.var));
        Vars = {'DGDP_e','DGDP_c', 'DI_e', 'DI_c', 'spread_e', 'spread_c'};
        for vvv=1:numel(Vars)
            Pos = find_incell(M_.endo_names, Vars{vvv});
            Regime(Regime_ID).Stds(vvv) = Stds(Pos);
        end
        
        Regime(Regime_ID).Taxes = [tau_k_e_obj tau_k_c_obj];

     	%Get tax correlations
        Pos_tau_k_e = find_incell(M_.endo_names, 'tau_k_e');
        Pos_tau_k_c = find_incell(M_.endo_names, 'tau_k_c');
        Pos_Delta_tau_k_e = find_incell(M_.endo_names, 'Delta_tau_k_e');
        Pos_Delta_tau_k_c = find_incell(M_.endo_names, 'Delta_tau_k_c');
        Regime(Regime_ID).TaxCorr = oo_.var(Pos_tau_k_e, Pos_tau_k_c)/sqrt(oo_.var(Pos_tau_k_e, Pos_tau_k_e)*oo_.var(Pos_tau_k_c, Pos_tau_k_c));
        Regime(Regime_ID).DeltaTaxCorr = oo_.var(Pos_Delta_tau_k_e, Pos_Delta_tau_k_c)/sqrt(oo_.var(Pos_Delta_tau_k_e, Pos_Delta_tau_k_e)*oo_.var(Pos_Delta_tau_k_c, Pos_Delta_tau_k_c));
        Regime(Regime_ID).DeltaTaxCov = oo_.var(Pos_Delta_tau_k_e, Pos_Delta_tau_k_c);            

        
        %Get utility and coefficient of variation for specific variables
        %Note that no_pen refers to without the tax aversion penalty NOT the timeless penalty
        Vars_to_Fetch = {'Util', 'Util_no_pen', 'UE', 'UE_no_pen', 'UC', 'UC_no_pen', 'Ce','Cc', 'He', 'Hc', 'spread_e', 'spread_c', 'Income_e', 'Income_c'};
        Pos=zeros(size(Vars_to_Fetch));
        for kkk = 1:numel(Vars_to_Fetch)
            Pos(kkk) = find_incell(M_.endo_names, Vars_to_Fetch{kkk});
        end

        %Timeless penalty currently unused
        TimelessPenalty = 0;


        
        
        %The Pos variable references to the positions of the following variables
        %'Util', 'Util_no_pen', 'UE', 'UE_no_pen', 'UC', 'UC_no_pen', 'Ce','Cc', 'He', 'Hc', 'spread_e', 'spread_c'};

        
        %Welfare
        %This takes into account the timeless penalty                     
        Regime(Regime_ID).Utils = Cond_Means(Pos(1:6)) + TimelessPenalty;
        Regime(Regime_ID).Utils_ss = SS(Pos(1:6));
        
          
        %First and second moments
        %These do not take into account the timeless penalty as it cannot be decomposed
        Regime(Regime_ID).CoefVars       = Stds(Pos(7:12))./Cond_Means(Pos(7:12));
        Regime(Regime_ID).CondMeanVars   = Cond_Means(Pos(7:12));
        Regime(Regime_ID).StdsVars       = Stds(Pos(7:12));
        Regime(Regime_ID).IncomeStds      = Stds(Pos(13:14));

   
        
        

        clc
        %Display moments
        %T = array2table([oo_.steady_state sqrt(diag(oo_.var)) ], 'RowNames', string(M_.endo_names), 'VariableNames', {'SS', 'Std'});
       
        
        %Save results
        save('Table_Results.mat', 'Regime', 'Regime_ID', 'alpha_k_Runs')

    end
    
    %Remove the saved structures to save space
    for rrr=1:numel(Regime)
        Regime(rrr).oo_ = [];
        Regime(rrr).M_ = [];
    end
    save('Table_Results.mat', 'Regime', 'Regime_ID', 'alpha_k_Runs')

end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Process Results
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc
load Table_Results.mat

%Optimal taxes
for Regime_ID = 1:numel(Regime)
    Taxes(Regime_ID, :) = Regime(Regime_ID).Taxes;
    Names{Regime_ID} = [num2str(Regime_ID)  ': ' Regime(Regime_ID).Name];
    Util_Res(Regime_ID, :) = Regime(Regime_ID).Utils';    
    IncomeStds(Regime_ID,:) = Regime(Regime_ID).IncomeStds';
    TaxCorrs(Regime_ID) = Regime(Regime_ID).DeltaTaxCorr;
end
disp(array2table([round(Taxes,2) round(Util_Res, 4), round(IncomeStds,4)], 'VariableNames', {'tau_k_e', 'tau_k_c', 'Util', 'Util_no_tax', 'UE', 'UE_no_tax', 'UC', 'UC_no_tax', 'Income_e', 'Income_c'}, 'RowNames', Names))
disp(' ')
tmp = 1:numel(Regime);
CoopRegimes = tmp(~isnan(str2num(cell2str(strfind(Names, 'Coop')))));
disp(array2table([round(Util_Res(CoopRegimes, :)-Util_Res(CoopRegimes+1, :), 4)*100], 'VariableNames', {'Util', 'Util_no_tax', 'UE', 'UE_no_tax', 'UC', 'UC_no_tax'}, 'RowNames', Names(CoopRegimes)))

disp(array2table([TaxCorrs(CoopRegimes)' TaxCorrs(CoopRegimes+1)'], 'VariableNames', {'TaxCorr_Coop', 'TaxCorr_Nash'}, 'RowNames', Names(CoopRegimes)))



%TABLES FOR PAPER





%Table b.10
%Get steady states
Vars = {'spread_e','spread_c', 'Leverage_e', 'Leverage_c', 'I_GDP_e', 'I_GDP_c'};
RegimesToShow = 10;
for vvv = [2 1 4 3 6 5]
    SS_Disp(vvv)=Regime(RegimesToShow).SS(vvv);
end

SS_Disp_Formatted(1:2)=round(SS_Disp(1:2)*4*10000, 0); %Convert spreads to annual basis points
SS_Disp_Formatted(3:4)=round(exp(SS_Disp(3:4)), 2); %Convert leverage to levels
SS_Disp_Formatted(5:6)=round(exp(SS_Disp(5:6))*100,1); %Convert I_GDP to levels (%)

disp([Regime(RegimesToShow).Name ' steady states'])
disp(' ')

StartLine = {'Spread AE (annual bp)        & ', 'Spread EME (annual bp)        & ', 'Leverage AE                  &   ', 'Leverage EME                  &   ', '$\frac{Investment}{GDP}$ AE&    ', '$\frac{Investment}{GDP}$ EME &   '};
EndLine = {'&221--660$^\dagger$\\', '&400--748$^{\dagger\dagger}$\\', '&6.14 -- 12.02$^\quarternote$\\', '&4.46 --7.94$^\quarternote$\\', '\%&24\%$^{\quarternote\quarternote}$\\', '\%& 24\%$^{\quarternote\quarternote}$\\'};

Table_B10 = '';
nnn=0;
for sss=[2 1 4 3 6 5]
    nnn=nnn+1;
    disp([Vars{sss} '   ' sprintf('%g\n', SS_Disp_Formatted(sss))])
    Table_B10 = [Table_B10 StartLine{nnn} sprintf('%g', SS_Disp_Formatted(sss)) EndLine{nnn}];
end

%clipboard('copy', Table_B10)


%Table b.11
%Get standard deviations
Vars = {'DGDP_e','DGDP_c', 'DI_e', 'DI_c', 'spread_e', 'spread_c'};
for vvv = 1:numel(Vars)
     Std_Disp(vvv)=Regime(RegimesToShow).Stds(vvv);
end

Std_Disp_Formatted(1:2)=round(Std_Disp(1:2)*100, 2); %Convert GDP growth to levels
Std_Disp_Formatted(3:4)=round(Std_Disp(3:4)*100, 2); %Convert I growth to levels
Std_Disp_Formatted(5:6)=round(Std_Disp(5:6)*4*10000,0); %Convert spreads to annual basis points



StartLine = {'Growth GDP EME & ', 'Growth GDP AE & ', 'Growth Investment EME & ', 'Growth Investment AE & ', 'Spread EME & ', 'Spread AE & '}; 
EndLine = {'&  $\underset{(0.57)}{1.17}$ \\ ', '& $\underset{(0.35)}{0.74}$\\ ', '&  $\underset{(21.48)}{7.48}$[median = 3.39]\\  ' ,'&  $\underset{(1.20)}{2.61}$\\  ', '&  $202-391$\\ ', '& $110-275$\\  '};

Table_B11 = '';
nnn=0;
for sss=1:6
    nnn=nnn+1;
    disp([Vars{sss} '   ' sprintf('%g\n', Std_Disp_Formatted(sss))])
    Table_B11 = [Table_B11 StartLine{nnn} sprintf('%g', Std_Disp_Formatted(sss)) EndLine{nnn}];
end

%clipboard('copy', Table_B11)










Table_3 = '';

Headers = {'\\\multicolumn{4}{l}{International RBC model}\\',...
            '\\\multicolumn{4}{l}{Symmetric model ($k_D=1$)}\\',...
            '\\\multicolumn{4}{l}{Asymmetric model ($k_D=\frac{1}{2}$)}\\',...
            '\\\multicolumn{4}{l}{Asymmetric model ($k_D=0$)}\\'};

Regimes_To_Show = [2 5 11 17]; %These are the Coop regimes for the above headers
for nnn = 1:numel(Regimes_To_Show)
    %Add header row
    Table_3 = [Table_3 Headers{nnn}];

    Coop_Taxes = Regime(Regimes_To_Show(nnn)).Taxes;
    Nash_Taxes = Regime(Regimes_To_Show(nnn)+1).Taxes;
    Taxes_Latex_Data = [Coop_Taxes Nash_Taxes]*100;
    for jjj=1:numel(Taxes_Latex_Data)-1
        Table_3 = [Table_3 sprintf('%.2f', Taxes_Latex_Data(jjj)) '\% & ' ];
    end
    Table_3 = [Table_3 sprintf('%.2f', Taxes_Latex_Data(end)) '\% \\ ' ];
end

%clipboard('copy',Table_3)


%Table 4: Welfare gain is simply Coop - Nash
Headers = {'\\\multicolumn{7}{l}{International RBC model}\\',...
            '\\\multicolumn{7}{l}{Symmetric model ($k_D=1$)}\\',...
            '\\\multicolumn{7}{l}{Asymmetric model ($k_D=\frac{1}{2}$)}\\',...
            '\\\multicolumn{7}{l}{Asymmetric model ($k_D=0$)}\\'};

Regimes_To_Show = [2 5 11 17]; %These are the Coop regimes for the above headers
clearvars RowNames
Table_4a = '';
Table_4b = '';
Table_4 = '';
for nnn = 1:numel(Regimes_To_Show)
    UtilDiff(nnn,:) = (Regime(Regimes_To_Show(nnn)).Utils - Regime(Regimes_To_Show(nnn)+1).Utils)'; %Coop - Nash (conditional means)
    Alpha_k_Res(nnn) = Regime(Regimes_To_Show(nnn)).tx_alpha_k;
    RowNames{nnn, :} = Regime(Regimes_To_Show(nnn)).Name;

    Table_4 = [Table_4 Headers{nnn}];

    Table_4 = [Table_4 sprintf('& %.2f\\%% & (%.2f\\%%)$^{\\dagger\\dagger}$ & %.2f\\%% & (%.2f\\%%)$^{\\dagger\\dagger}$ & %.2f\\%% & (%.2f\\%%)$^{\\dagger\\dagger}$ \\\\', UtilDiff(nnn,:)*100)];

end

%    clipboard('copy',Table_4)


disp(array2table(round(UtilDiff*100,2), 'VariableNames', {'Util', 'Util_no_tax', 'UE', 'UE_no_tax', 'UC', 'UC_no_tax'}, 'RowNames', string(RowNames)))
disp(' ')




%Tax share as a percentage of global 
Regimes_To_Show = [2 5 11 17]; %These are the Coop regimes for the above headers
clearvars RowNames
for nnn = 1:numel(Regimes_To_Show)
    RowNames{nnn, :} = Regime(Regimes_To_Show(nnn)).Name;
    TaxShare_Coop(nnn, :) = (Regime(Regimes_To_Show(nnn)).Utils(2)-Regime(Regimes_To_Show(nnn)).Utils(1))/Regime(Regimes_To_Show(nnn)).Utils(2);
    TaxShare_Nash(nnn, :) = (Regime(Regimes_To_Show(nnn)+1).Utils(2)-Regime(Regimes_To_Show(nnn)+1).Utils(1))/Regime(Regimes_To_Show(nnn)+1).Utils(2);
end
disp(array2table(round([TaxShare_Coop*100 TaxShare_Nash*100],2), 'VariableNames', {'Coop', 'Nash'}, 'RowNames', RowNames))
disp(' ')




clearvars RowNames
%Extract results 

RegimesToShow = 1:numel(Regime);%[1 3 2 4 6 5 10 12 11 16 18 17];
for nnn = 1:numel(RegimesToShow)
    CoefVar_Res(nnn, :)   = Regime(RegimesToShow(nnn)).CoefVars;   
    Mean_Res(nnn, :)   = [exp(Regime(RegimesToShow(nnn)).CondMeanVars(1:4)); Regime(RegimesToShow(nnn)).CondMeanVars(5:6)]; 
    Stds_Res(nnn, :)   = Regime(RegimesToShow(nnn)).StdsVars*100; 
    UtilVar_Res(nnn, :) = Regime(RegimesToShow(nnn)).Utils(3:6);  %Omit the global welfare (cols 1:2)
    RowNames{nnn, :} = [num2str(nnn) ': ' Regime(RegimesToShow(nnn)).Name];
end


%Table 5: Coefficient of variation, Means and Stds tables

%disp(array2table(round(CoefVar_Res,4), 'VariableNames', {'Ce','Cc', 'He', 'Hc', 'spread_e', 'spread_c'}, 'RowNames', RowNames))
disp(' ')
disp('Means')
disp(' ')
disp(array2table(round(Mean_Res,4).*[1 1 1 1 100 100], 'VariableNames', {'Ce','Cc', 'He', 'Hc', 'spread_e', 'spread_c'}, 'RowNames', RowNames))
disp(' ')
disp('Stds')
disp(' ')
disp(array2table(round(Stds_Res,4).*[1 1 1 1 100 100], 'VariableNames', {'Ce','Cc', 'He', 'Hc', 'spread_e', 'spread_c'}, 'RowNames', RowNames))
disp(' ')

Headers={'No MaP', 'Nash', 'Cooperation'};

Table_7a = '';
Table_7b = '';
for kk=1:4 %The difference parameterizations
    switch kk
        case 1
            TitleRow = '\multicolumn{8}{U{\dimexpr\textwidth-2\tabcolsep}}{IRBC}\\   ';
            RegimesToShow = 2:3; %Skip No MaP
        case 2
            TitleRow = '\multicolumn{8}{U{\dimexpr\textwidth-2\tabcolsep}}{FF with symmetry, $k_D=1$}\\   ';
            RegimesToShow = [4 6 5]; %No MaP, Nash, Coop
        case 3 
            TitleRow= '\multicolumn{8}{U{\dimexpr\textwidth-2\tabcolsep}}{FF with asymmetry, $k_D=0.5$}\\   ';
            RegimesToShow = [10 12 11]; %No MaP, Nash, Coop
        case 4
            TitleRow= '\multicolumn{8}{U{\dimexpr\textwidth-2\tabcolsep}}{FF greater asymmetry, $k_D=0$}\\   ';
            RegimesToShow = [16 18 17]; %No MaP, Nash, Coop
    end
    
    Table_7a = [Table_7a TitleRow];
    Table_7b = [Table_7b TitleRow];
    nnn=0;
    for jjj=1:numel(RegimesToShow)
        nnn=nnn+1;
        Table_7a = [Table_7a '&' Headers{nnn}];
        Table_7b = [Table_7b '&' Headers{nnn}];
        
        if ismember(kk, [1 2]) %For symmetric parameterizations
            VariablesToShow = [1 3 5]; %Only show one due to symmetry
            Additional1 = '\multicolumn{2}{c}{';
            Additional2 = '}';
        else
            VariablesToShow = 1:6;
            Additional1='';
            Additional2='';
        end
        for lll=VariablesToShow %The different variables
            if ismember(lll, [5 6])
                Table_7a = [Table_7a ' & ' Additional1 sprintf('%g', round(Mean_Res(RegimesToShow(jjj),lll)*400*100,0)) Additional2];
                Table_7b = [Table_7b ' & ' Additional1 sprintf('%g', round(Stds_Res(RegimesToShow(jjj),lll)*400,0)) Additional2];
            else
                Table_7a = [Table_7a ' & ' Additional1 sprintf('%g', round(Mean_Res(RegimesToShow(jjj),lll),3)) Additional2];
                Table_7b = [Table_7b ' & ' Additional1 sprintf('%g', round(Stds_Res(RegimesToShow(jjj),lll),3)) Additional2];
            end
        end
        Table_7a = [Table_7a '\\'];
        Table_7b = [Table_7b '\\'];
    end
end
Table_7 = ['\multicolumn{2}{l}{Conditional Mean}&$C^e$&$C^c$&$H^e$&$H^c$&$spread^e{}^\dagger$&$spread^c{}^\dagger$  \\ \hline ' Table_7a ...
                '\\\multicolumn{2}{l}{Standard Deviation$^{\dagger\dagger}$}&$C^e$&$C^c$&$H^e$&$H^c$&$spread^e{}^\dagger$&$spread^c{}^\dagger$  \\ \hline ' Table_7b];


%clipboard('copy',Table_7)



%Tax correlations
Regimes_To_Show = [2 5 8 11 14 17]; %These are the coop regimes 
clearvars RowNames

for nnn = 1:numel(Regimes_To_Show)
    TaxCorr_Coop(nnn, :) = [Regime(Regimes_To_Show(nnn)).DeltaTaxCov*1e6 Regime(Regimes_To_Show(nnn)).DeltaTaxCorr];
    TaxCorr_Nash(nnn, :) = [Regime(Regimes_To_Show(nnn)+1).DeltaTaxCov*1e6 Regime(Regimes_To_Show(nnn)+1).DeltaTaxCorr];
    RowNames{nnn, :} = Regime(Regimes_To_Show(nnn)).Name;
end

disp(array2table(round([TaxCorr_Coop TaxCorr_Nash],2), 'VariableNames', {'Coop_Delta_Tau_Cov' 'Coop_Delta_Tau_Corr', 'Nash_Delta_Tau_Cov', 'Nash_Delta_Tau_Corr'}, 'RowNames', RowNames))
disp(' ')

Headers={'International RBC model', 'Symmetric FF model ($k_D=1$)', 'Asymmetric FF model ($k_D=0.75$)', 'Asymmetric FF model ($k_D=0.5$)', 'Asymmetric FF model ($k_D=0.25$)', 'Asymmetric FF model ($k_D=0$)'};
Table_8 = '';
ShowCorrelation=1;  %0 is covariance
for nnn=1:numel(Regimes_To_Show)
    Table_8 = [Table_8 Headers{nnn} '&' sprintf('%g & %g', round([TaxCorr_Coop(nnn,ShowCorrelation+1) TaxCorr_Nash(nnn,ShowCorrelation+1)], 2)) '\\'];
end
%clipboard('copy', Table_8)

