function [Regime, alpha_k_Runs] = Set_Up_Table_Regimes()

    %Set up all the regimes to run over
    %Regimes are run in pairs with the 1st being used as the baseline and the conditional means of the second compared to the first.
    gamma_k = 0.05;%0.2;
    
    %DECLARE THE BASE REGIMES FIRST
    %Detail the base regime, which is the initial values used for calculating the conditional means
    %The flag that this policy is a base regime is that the Base_Regime is the same as the Regime_ID
    nnn=0;
    for Size = [0.5]
    
        nnn=nnn+1;

        %%%%%%%%WITHOUT FINANCIAL FRICTIONS

        %Set the No MaP as the Base regime
        Base_Regime_ID = nnn;

        Regime(nnn).Name = ['IRBC, k_D=1, n = ' num2str(Size)];
        Regime(nnn).Policy_Regime = 4; %1 is both countries optimizing; 2 is EME only; 3 is AE only
        Regime(nnn).tx_alpha_k = 0; %Doesn't matter what this is as zero taxes
        Regime(nnn).tx_gamma_k = gamma_k; %Doesn't matter what this is as zero taxes
        Regime(nnn).nash_param = 1; %NOTE THAT 0 is NASH
        Regime(nnn).Base_Regime = Base_Regime_ID; %Set this number to be the same as the Regime_ID if it is a base regime, then the code will save the results and pass to cond_mom. Otherwise, set this number to the number of the base regime you want to compare to.
        Regime(nnn).ffr = 0; %Financial frictions
        Regime(nnn).n = Size; %Size
        Regime(nnn).k_D = 1; %k_D;  %Share of deposits

        nnn=nnn+1;

        %Coop
        Regime(nnn).Name = ['IRBC, Coop, k_D=1, n = ' num2str(Size)];
        Regime(nnn).Policy_Regime = 1; %1 is both countries optimizing; 2 is EME only; 3 is AE only
        Regime(nnn).tx_alpha_k = 0;
        Regime(nnn).tx_gamma_k = gamma_k;
        Regime(nnn).nash_param = 1; %NOTE THAT 0 is NASH
        Regime(nnn).Base_Regime = Base_Regime_ID; %This means that you use Regime_ID = Base_Regime_ID as the base regime
        Regime(nnn).ffr = 0; %Financial frictions
        Regime(nnn).n = Size; %Size
        Regime(nnn).k_D = 1; %k_D;  %Share of deposits


        nnn=nnn+1;

        %Nash
        Regime(nnn).Name = ['IRBC, Nash, k_D=1, n = ' num2str(Size)];
        Regime(nnn).Policy_Regime = 1; %1 is both countries optimizing; 2 is EME only; 3 is AE only
        Regime(nnn).tx_alpha_k = 0;
        Regime(nnn).tx_gamma_k = gamma_k;
        Regime(nnn).nash_param = 0; %NOTE THAT 0 is NASH
        Regime(nnn).Base_Regime = Base_Regime_ID; %This means that you use Regime_ID = Base_Regime_ID as the base regime
        Regime(nnn).ffr = 0; %Financial frictions
        Regime(nnn).n = Size; %Size
        Regime(nnn).k_D = 1; %k_D;  %Share of deposits


        %%%%%%%%%% WITH FINANCIAL FRICTIONS
        
        
        for k_D = [1 0.75 0.5 0.25 0]
        

            nnn=nnn+1;

            %WITH FINANCIAL FRICTIONS

            %Set the No MaP as the base regime
            Base_Regime_ID = nnn;

            Regime(nnn).Name = ['FF: No MaP, k_D=' num2str(k_D) ', n = ' num2str(Size)];
            Regime(nnn).Policy_Regime = 4; %1 is both countries optimizing; 2 is EME only; 3 is AE only
            Regime(nnn).tx_alpha_k = 0; %Doesn't matter what this is as zero taxes
            Regime(nnn).tx_gamma_k = gamma_k; %Doesn't matter what this is as zero taxes
            Regime(nnn).nash_param = 1; %NOTE THAT 0 is NASH
            Regime(nnn).Base_Regime = Base_Regime_ID; %Set this number to be the same as the Regime_ID if it is a base regime, then the code will save the results and pass to cond_mom. Otherwise, set this number to the number of the base regime you want to compare to.
            Regime(nnn).ffr = 1; %Financial frictions
            Regime(nnn).n = Size; %Size
            Regime(nnn).k_D = k_D;  %Share of deposits

            
            if Size ==0.5
                alpha_k = [0];  %4 works
            else
                alpha_k = [0]; 
            end
            alpha_k_Runs = numel(alpha_k);


            for kkk = 1:numel(alpha_k)
                nnn=nnn+1;

                %Coop
                Regime(nnn).Name = ['FF: Coop, alpha_k = ' num2str(alpha_k(kkk)) ', k_D=' num2str(k_D) ', n = ' num2str(Size)];
                Regime(nnn).Policy_Regime = 1; %1 is both countries optimizing; 2 is EME only; 3 is AE only
                Regime(nnn).tx_alpha_k = alpha_k(kkk);
                Regime(nnn).tx_gamma_k = gamma_k;
                Regime(nnn).nash_param = 1; %NOTE THAT 0 is NASH
                Regime(nnn).Base_Regime = Base_Regime_ID; %This means that you use Regime_ID = Base_Regime_ID as the base regime
                Regime(nnn).ffr = 1; %Financial frictions
                Regime(nnn).n = Size; %Size
                Regime(nnn).k_D = k_D;  %Share of deposits

                nnn=nnn+1;

                %Nash
                Regime(nnn).Name = ['FF: Nash, alpha_k = ' num2str(alpha_k(kkk)) ', k_D=' num2str(k_D) ', n = ' num2str(Size)];
                Regime(nnn).Policy_Regime = 1; %1 is both countries optimizing; 2 is EME only; 3 is AE only
                Regime(nnn).tx_alpha_k = alpha_k(kkk);
                Regime(nnn).tx_gamma_k = gamma_k;
                Regime(nnn).nash_param = 0; %NOTE THAT 0 is NASH
                Regime(nnn).Base_Regime = Base_Regime_ID; %This means that you use Regime_ID = Base_Regime_ID as the base regime
                Regime(nnn).ffr = 1; %Financial frictions
                Regime(nnn).n = Size; %Size
                Regime(nnn).k_D = k_D;  %Share of deposits

            end

            if 0
                nnn=nnn+1;

                %EME only: Coop
                Regime(nnn).Name = 'EME only';
                Regime(nnn).Policy_Regime = 2; %1 is both countries optimizing; 2 is EME only; 3 is AE only; 4 is No Map
                Regime(nnn).tx_alpha_k = alpha_k(1);
                Regime(nnn).tx_gamma_k = gamma_k;
                Regime(nnn).nash_param = 1; %NOTE THAT 0 is NASH
                Regime(nnn).Base_Regime = Base_Regime_ID; %This means that you use Regime_ID = Base_Regime_ID as the base regime
                Regime(nnn).ffr = 1; %Financial frictions
                Regime(nnn).n = Size; %Size
                Regime(nnn).k_D = k_D;  %Share of deposits

                nnn=nnn+1;

                %AE only: Coop
                Regime(nnn).Name = 'AE only';
                Regime(nnn).Policy_Regime = 3; %1 is both countries optimizing; 2 is EME only; 3 is AE only; 4 is No Map
                Regime(nnn).tx_alpha_k = alpha_k(1);
                Regime(nnn).tx_gamma_k = gamma_k;
                Regime(nnn).nash_param = 1; %NOTE THAT 0 is NASH
                Regime(nnn).Base_Regime = Base_Regime_ID; %This means that you use Regime_ID = Base_Regime_ID as the base regime
                Regime(nnn).ffr = 1; %Financial frictions
                Regime(nnn).n = Size; %Size
                Regime(nnn).k_D = k_D;  %Share of deposits

            end

        end
    end
    if 0
        %Check base regimes
        clc
        for nnn=1:numel(Regime)
            disp([num2str(nnn) ':' Regime(nnn).Name ' has Base of ' num2str(Regime(nnn).Base_Regime) ' ' Regime(Regime(nnn).Base_Regime).Name])
        end
    end
end