
*** Finance and macroeconomic performance. Is there a role for macroprudential policies?
**SF, QR Sept 2017
* table A6

clear
cd "L:\DRS\Projects\2016_Gambacorta\Agenor_Kharroubi_Gambacorta_Lombardo_Pereira\Tables"

use Dataset_Vol.dta


* replace with Cerutti's database for 2013 and 2014
replace ACT_maps_total = atotalC if year==2013 | year==2014 
replace ACT_res = aresilienceC if year==2013 | year==2014 
replace ACT_cycl = acyclicalC if year==2013 | year==2014 

gen nindWB101=.
replace nindWB101=0 if year==2012 | year==2013 | year==2014
replace indWB101=nindWB101 if indWB101==.
replace indWB101=0 if COUNTRY=="Taiwan"
replace indWB101=1 if COUNTRY=="Taiwan" & year==1998
*tsegen indWB101_A5=rowmean(L(0/4).indWB101)

* merge with the linkages indicator
* source: Francesco Manaresi
merge 1:1 COUNTRY year using weights_matrix_contagion.dta
drop _merge

tsset newid year
*=============== extraaa
* macroprudential activism
foreach var in ACT_maps_total ACT_res ACT_cycl {
tsegen `var'_5y = rowtotal(L(0/4).`var') 
}



*generate the log of the MP
tsset  newid year 
foreach var in ACT_maps_total_5y ACT_res_5y ACT_cycl_5y{
gen log_`var' = log(`var'+1)
}

* generate intercations terms
*==== FD, FM and FI===
* FD * MP index
foreach var in log_ACT_maps_total_5y log_ACT_res_5y log_ACT_cycl_5y{
	gen MP_O_`var' = `var'*kaopen   /* MP index x Openness */
	foreach x in FD {
	
	gen `x'_MP_`var' = `x'*`var'   /* FD/FM/FI x MP index */
	gen `x'_MP_O_`var' = `x'*`var'*kaopen  /* FD/FM/FI x MP index x Openness */
	
}
}

foreach x in FD {
 gen `x'_O= `x'*kaopen   /* FD/FM/FI x  Openness */
}

* generate 5y averages of the vars involved in the regressions

foreach var of varlist ACT_maps_total_liab_S - ACT_cycl_rfLink_M log_ACT_maps_total_5y - FD_O indWB101 FD kaopen log_Schooling log_govCons ninflation_defl rwVol1 inflation_defl rwVol2 outvolGDPcap rwVol2a rwVol3a realIR realIR_IMF ote{
tsegen `var'_A5=rowmean(L(0/4).`var')  

}


** option 1: supervisory index as the average of all the surveys
foreach var in CapRegInd IndSupBank IndSupFT IndSupO  IndSupPol OffSupPow {
bysort COUNTRY: egen av`var'=mean(`var')

}


** option 2: use the same value for the previous years
foreach var in CapRegInd IndSupBank IndSupFT IndSupO  IndSupPol OffSupPow {
bysort COUNTRY: replace `var'=`var'[_n-1] if `var'==.
}


foreach var in CapRegInd IndSupBank IndSupFT IndSupO  IndSupPol OffSupPow{

bysort COUNTRY  : egen `var'_f=first(`var')
tsset newid year
bysort COUNTRY (`var'_f): replace `var'=`var'_f[1] if `var'==.
tsset newid year
}

* To create time dummies
*for 5y intervals
forvalues bot=1980(5)2014 {
	local top=`bot'+4
	gen years_`bot'_`top' = year >= `bot' & year <= `top' ///
		if !missing(year)
}




* IR
tsset newid year
replace realIR_A5 = realIR_IMF_A5 if realIR_A5==.
tsset newid year
bysort COUNTRY  : egen realIR_A5_f=first(realIR_A5)
tsset newid year
bysort COUNTRY (realIR_A5_f): replace realIR_A5_f=realIR_A5_f[1]
tsset newid year
replace realIR_A5=realIR_A5_f if realIR_A5==.
tsset newid year
* for each year
xi i.year, prefix(I)
gen T=year
tostring T, replace
gen dummy=.
replace dummy=1 if year==1979 | year == 1984 | year==1989 | year==1994 | year==1999 | year==2004 | year==2009 | year==2014
gen dummy1=.
replace dummy1=1 if year==1979 | year == 1983 | year==1988 | year==1993 | year==1998 | year==2003 | year==2008 | year==2013
*replace dummy=1 if   year==1994 | year==1999 | year==2004 | year==2009 | year==2014



*======================================================================================
* Volatility regressions
*======================================================================================
keep if dummy==1
duplicates drop
replace year=0 if year==1979
replace year=1 if year==1984
replace year=2 if year==1989
replace year=3 if year==1994
replace year=4 if year==1999
replace year=5 if year==2004	
replace year=6 if year==2009
replace year=7 if year==2014	
tsset newid year

*==========================================================================================================================
* version 3:same specification as in the SF + the linkages (claims) indicator + trade linkages (without interaction with OPEN)
*===========================================================================================================================
*MaP Total


xtabond2 rwVol2a l.rwVol2a i_gdprl_f  log_ACT_maps_total_5y_A5 FD_A5  kaopen_A5  FD_MP_log_ACT_maps_total_5y_A5   ACT_maps_total_claims_S_A5 ACT_maps_total_Trade_M_A5 log_Schooling_A5 log_govCons_A5 inflation_defl_A5 IndSupFT realIR_A5 ote_A5 indWB101_A5 years_*  if dummy==1  , gmmstyle(l.rwVol2a , lag(1 2) collapse) /// 
	ivstyle ( l.(0/0)(i_gdprl_f FD_A5 log_ACT_maps_total_5y_A5 kaopen_A5  FD_MP_log_ACT_maps_total_5y_A5  ACT_maps_total_claims_S_A5 ACT_maps_total_Trade_M_A5 log_Schooling_A5 log_govCons_A5 inflation_defl_A5 realIR_A5 ote_A5 ) indWB101_A5 IndSupFT years_*  )   nomata  robust

outreg2 using  "L:\DRS\Projects\2016_Gambacorta\Agenor_Kharroubi_Gambacorta_Lombardo_Pereira\Tables\TableA6raw.xls",  dec(4)	

*Resilience

 xtabond2 rwVol2a l.rwVol2a i_gdprl_f  log_ACT_res_5y_A5 FD_A5   kaopen_A5  FD_MP_log_ACT_res_5y_A5  ACT_res_claims_S_A5 ACT_res_Trade_M_A5 log_Schooling_A5 log_govCons_A5 inflation_defl_A5 IndSupPol realIR_A5 ote_A5 indWB101_A5 years_*  if dummy==1 , gmmstyle(l.rwVol2a , lag(1 2) collapse) /// 
	ivstyle (l.(0/0)(i_gdprl_f  FD_MP_log_ACT_res_5y_A5  FD_A5 log_ACT_res_5y_A5 kaopen_A5  ACT_res_claims_S_A5 ACT_res_Trade_M_A5 log_Schooling_A5 log_govCons_A5 inflation_defl_A5   realIR_A5 ote_A5 ) indWB101_A5 years_*  IndSupPol) nomata 

outreg2 using  "L:\DRS\Projects\2016_Gambacorta\Agenor_Kharroubi_Gambacorta_Lombardo_Pereira\Tables\TableA6raw.xls",  dec(4)	
	
	
*Cyclical

xtabond2 rwVol2a l.rwVol2a i_gdprl_f  log_ACT_cycl_5y_A5 FD_A5    kaopen_A5  FD_MP_log_ACT_cycl_5y_A5  ACT_cycl_claims_S_A5 ACT_cycl_Trade_M_A5 log_Schooling_A5 log_govCons_A5 inflation_defl_A5  IndSupFT realIR_A5 ote_A5 indWB101_A5 years_*  if dummy==1 , gmmstyle(l.rwVol2a , lag(1 2) collapse) /// 
	ivstyle (l.(0/0)( i_gdprl_f  FD_A5 log_ACT_cycl_5y_A5   kaopen_A5  FD_MP_log_ACT_cycl_5y_A5  ACT_cycl_claims_S_A5 ACT_cycl_Trade_M_A5 log_Schooling_A5 log_govCons_A5 inflation_defl_A5 realIR_A5 ote_A5)  indWB101_A5 IndSupFT  years_*  )  nomata  robust

outreg2 using  "L:\DRS\Projects\2016_Gambacorta\Agenor_Kharroubi_Gambacorta_Lombardo_Pereira\Tables\TableA6raw.xls",  dec(4)	

