
***===================================================
* The international dimensions of macroprudential policies
*===================================================
* table A7: Interdependence of macroprudential tools among countries


cd "L:\DRS\Projects\2016_Gambacorta\Agenor_Kharroubi_Gambacorta_Lombardo_Pereira\Tables"

clear
use NTradeData
drop rr rr_2

*================== new - from Francesco
g net=claims-liab
g tover=claims+liab
egen tover2=rowtotal(claims liab)
egen Trade=rowtotal(exports imports)
rename exports exp
rename imports imp

* Weights Fixed Overtime
foreach x in  claims Trade {
	preserve
		keep if `x'!=.
		bys COUNTRY_2 year: egen tot`x'=total(`x')
		g `x'sh=`x'/tot`x'
		collapse (mean) `x'sh , by(COUNTRY COUNTRY_2)
		tempfile `x'weight
		save ``x'weight'
	restore
	merge m:1 COUNTRY COUNTRY_2 using ``x'weight', gen(m`x'weight) keep(1 3)
}


* 3-Years Moving Averages
foreach x in claims Trade {
	preserve
		keep if `x'!=.
		egen idtemp=group(COUNTRY COUNTRY_2)
		tsset idtemp year, yearly
		tssmooth ma MA`x'=`x', window(3,0,0)
		bys COUNTRY_2 year: egen totMA`x'=total(MA`x')
		g MA`x'sh=MA`x'/totMA`x'
		collapse (mean) MA`x'sh , by(COUNTRY COUNTRY_2)
		tempfile `x'weightMA
		save ``x'weightMA'
	restore
	merge m:1 COUNTRY COUNTRY_2 using ``x'weightMA', gen(m`x'weightMA) keep(1 3)
}

* Loop to Gen Components of Weighted Average
foreach x in maps_total res_total cycl_total {
	foreach y in claims Trade {
		g `x'_`y'_S=`x'*`y'sh
		g `x'_`y'_M=`x'*MA`y'sh
	}
}



*rename vars
rename capital_based cb
rename liquidity_based lb
rename asset_side as
rename reserve_requirement rr
rename currency_instruments ci
rename capital_based_2 cb_2
rename liquidity_based_2 lb_2
rename asset_side_2 as_2
rename reserve_requirement_2 rr_2
rename currency_instruments_2 ci_2
*resilience measures
gen res = cb + lb
gen res_2 = cb_2 + lb_2
*cyclical measures
gen cycl =  as + rr + ci
gen cycl_2 =  as_2 + rr_2 + ci_2

sort COUNTRY COUNTRY_2 year

*generate interaction terms

drop newid
egen newid = group(COUNTRY)
// To create time dummies
xi i.year, prefix(I)
gen T=year
tostring T, replace

// To create Countr1*Country2 dummies

gen C1=newid
tostring C1, replace
gen C2=newid
tostring C2, replace
gen CC=C1+C2
xi i.CC, prefix(D)

*generate binary variable: 1 if action, 0 if not
foreach var in  maps_total res_total cycl_total {
gen bin_`var'=.
bysort COUNTRY COUNTRY_2: replace bin_`var'=1 if `var'!=0
replace bin_`var'=0 if bin_`var'==.
}

foreach var in COUNTRY COUNTRY_2{
replace `var'="Czech_Republic" if `var'=="Czech Republic"
replace `var'="Slovak_Republic" if `var'=="Slovak Republic"	
replace `var'="United_Kingdom" if `var'=="United Kingdom"		
}	
gen dum_EU=.

foreach var in Austria	Belgium	Bulgaria	Croatia	Czech_Republic	Denmark	Estonia	Finland	France	Germany	Greece	Hungary	Ireland	Italy	Latvia	Lithuania	Luxembourg	Malta	Netherlands	Poland	Portugal	Romania	Slovak_Republic	Slovenia	Spain	Sweden	United_Kingdom {
foreach var2 in Austria	Belgium	Bulgaria	Croatia	Czech_Republic	Denmark	Estonia	Finland	France	Germany	Greece	Hungary	Ireland	Italy	Latvia	Lithuania	Luxembourg	Malta	Netherlands	Poland	Portugal	Romania	Slovak_Republic	Slovenia	Spain	Sweden	United_Kingdom {

replace dum_EU=1 if COUNTRY=="`var'" & COUNTRY_2=="`var2'"
	}
	}
	
replace dum_EU=0 if dum_EU==.
sort COUNTRY COUNTRY_2 year
* generate a new var (gdp2 / gdp1) for the size
bysort COUNTRY COUNTRY_2 : gen size_gdp= gdp2  / gdp1 if gdp1!=. & gdp2!=.
gen lsize_gdp = log(size_gdp)


sort COUNTRY COUNTRY_2 year
* generate a new var (FD2 / FD1) for the fin development and efficiency and depth
bysort COUNTRY COUNTRY_2 : gen share_FD= FD2  / FD1 if FD1!=. & FD2!=.
bysort COUNTRY COUNTRY_2 : gen size_FD= FD2  - FD1 if FD1!=. & FD2!=.
bysort COUNTRY COUNTRY_2 : gen share_eff= (FIE2 + FME2)/(FIE1 + FME1)   if FIE1!=. & FIE2!=. & FME1!=. & FME2!=.
bysort COUNTRY COUNTRY_2 : gen share_dep= (FID2 + FMD2)/(FID1 + FMD1)   if FID1!=. & FID2!=. & FMD1!=. & FMD2!=.
bysort COUNTRY COUNTRY_2 : gen share_cspread= cspread2  / cspread1 if cspread1!=. & cspread2!=.
bysort COUNTRY COUNTRY_2 : gen share_gdp= gdp2  / gdp1 if gdp1!=. & gdp2!=.
gen lshare_cspread = log(share_cspread)
gen lshare_gdp = log(share_gdp)

*interaction terms - not everything is used 
*macropru X (FD) size
foreach var in maps_total_2 res_total_2 cycl_total_2{
foreach x in size_gdp share_FD size_FD share_eff share_dep lshare_cspread lshare_gdp{
gen `var'_`x' = `var'*`x'
}
}

* EU dummy
foreach var in maps_total_2 res_total_2 cycl_total_2{
gen `var'_dEU=`var'*dum_EU
}


************************************

** baseline Table 2 with claims / trade
*================================
* claims
*================================
* the option beta provides a third row in the output which corresponds to the standardized beta coefficients


* part 2: interaction with Xs	
foreach varX in share_FD   {
foreach var in maps_total res_total cycl_total {
preserve	
	rename `var'_2 Macropru2
	rename `var'_claims_S Macropru2F
	rename `var'_Trade_S Macropru2T
	rename `var'_2_dEU Macropru2EU
	rename `var'_2_`varX' Macropru2_X  

	reg `var' Macropru2  Macropru2T Macropru2F Macropru2EU Macropru2_X gr_gdp1 gr_gdp2 DCC*
	*outreg2 using  Table2c.tex,  dec(4)  stats(coef, se, beta)
	outreg2 using  "L:\DRS\Projects\2016_Gambacorta\Agenor_Kharroubi_Gambacorta_Lombardo_Pereira\Tables\TableA7.xls",  dec(4)  stats(coef, se, beta)	
restore
}
}

